import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.likes import (
    AddResponse,
    AddResponseModel,
    DeleteResponse,
    DeleteResponseModel,
    GetListExtendedResponse,
    GetListExtendedResponseModel,
    GetListResponse,
    GetListResponseModel,
    IsLikedResponse,
    IsLikedResponseModel,
)


class LikesCategory(BaseCategory):
    async def add(
        self,
        type: str,
        item_id: int,
        owner_id: typing.Optional[int] = None,
        access_key: typing.Optional[str] = None,
        **kwargs
    ) -> AddResponseModel:
        """Adds the specified object to the 'Likes' list of the current user.

        :param type: Object type: 'post' — post on user or community wall, 'comment' — comment on a wall post, 'photo' — photo, 'audio' — audio, 'video' — video, 'note' — note, 'photo_comment' — comment on the photo, 'video_comment' — comment on the video, 'topic_comment' — comment in the discussion, 'sitepage' — page of the site where the [vk.com/dev/Like|Like widget] is installed
        :param item_id: Object ID.
        :param owner_id: ID of the user or community that owns the object.
        :param access_key: Access key required for an object owned by a private entity.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("likes.add", params)
        model = AddResponse
        return model(**response).response

    async def delete(
        self,
        type: str,
        item_id: int,
        owner_id: typing.Optional[int] = None,
        access_key: typing.Optional[str] = None,
        **kwargs
    ) -> DeleteResponseModel:
        """Deletes the specified object from the 'Likes' list of the current user.

        :param type: Object type: 'post' — post on user or community wall, 'comment' — comment on a wall post, 'photo' — photo, 'audio' — audio, 'video' — video, 'note' — note, 'photo_comment' — comment on the photo, 'video_comment' — comment on the video, 'topic_comment' — comment in the discussion, 'sitepage' — page of the site where the [vk.com/dev/Like|Like widget] is installed
        :param item_id: Object ID.
        :param owner_id: ID of the user or community that owns the object.
        :param access_key: Access key required for an object owned by a private entity.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("likes.delete", params)
        model = DeleteResponse
        return model(**response).response

    @typing.overload
    async def get_list(
        self,
        type: str,
        owner_id: typing.Optional[int] = None,
        item_id: typing.Optional[int] = None,
        page_url: typing.Optional[str] = None,
        filter: typing.Optional[Literal["likes", "copies"]] = None,
        friends_only: typing.Optional[Literal[0, 1, 2, 3]] = None,
        extended: typing.Optional[Literal[False]] = ...,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        skip_own: typing.Optional[bool] = None,
        **kwargs
    ) -> GetListResponseModel:
        ...

    @typing.overload
    async def get_list(
        self,
        type: str,
        owner_id: typing.Optional[int] = None,
        item_id: typing.Optional[int] = None,
        page_url: typing.Optional[str] = None,
        filter: typing.Optional[Literal["likes", "copies"]] = None,
        friends_only: typing.Optional[Literal[0, 1, 2, 3]] = None,
        extended: Literal[True] = ...,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        skip_own: typing.Optional[bool] = None,
        **kwargs
    ) -> GetListExtendedResponseModel:
        ...

    async def get_list(
        self,
        type=None,
        owner_id=None,
        item_id=None,
        page_url=None,
        filter=None,
        friends_only=None,
        extended=None,
        offset=None,
        count=None,
        skip_own=None,
        **kwargs
    ) -> typing.Union[GetListResponseModel, GetListExtendedResponseModel]:
        """Returns a list of IDs of users who added the specified object to their 'Likes' list.

        :param type: , Object type: 'post' — post on user or community wall, 'comment' — comment on a wall post, 'photo' — photo, 'audio' — audio, 'video' — video, 'note' — note, 'photo_comment' — comment on the photo, 'video_comment' — comment on the video, 'topic_comment' — comment in the discussion, 'sitepage' — page of the site where the [vk.com/dev/Like|Like widget] is installed
        :param owner_id: ID of the user, community, or application that owns the object. If the 'type' parameter is set as 'sitepage', the application ID is passed as 'owner_id'. Use negative value for a community id. If the 'type' parameter is not set, the 'owner_id' is assumed to be either the current user or the same application ID as if the 'type' parameter was set to 'sitepage'.
        :param item_id: Object ID. If 'type' is set as 'sitepage', 'item_id' can include the 'page_id' parameter value used during initialization of the [vk.com/dev/Like|Like widget].
        :param page_url: URL of the page where the [vk.com/dev/Like|Like widget] is installed. Used instead of the 'item_id' parameter.
        :param filter: Filters to apply: 'likes' — returns information about all users who liked the object (default), 'copies' — returns information only about users who told their friends about the object
        :param friends_only: Specifies which users are returned: '1' — to return only the current user's friends, '0' — to return all users (default)
        :param extended: Specifies whether extended information will be returned. '1' — to return extended information about users and communities from the 'Likes' list, '0' — to return no additional information (default)
        :param offset: Offset needed to select a specific subset of users.
        :param count: Number of user IDs to return (maximum '1000'). Default is '100' if 'friends_only' is set to '0', otherwise, the default is '10' if 'friends_only' is set to '1'.
        :param skip_own:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("likes.getList", params)
        model = self.get_model(
            ((("extended",), GetListExtendedResponse),),
            default=GetListResponse,
            params=params,
        )
        return model(**response).response

    async def is_liked(
        self,
        type: str,
        item_id: int,
        user_id: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs
    ) -> IsLikedResponseModel:
        """Checks for the object in the 'Likes' list of the specified user.

        :param type: Object type: 'post' — post on user or community wall, 'comment' — comment on a wall post, 'photo' — photo, 'audio' — audio, 'video' — video, 'note' — note, 'photo_comment' — comment on the photo, 'video_comment' — comment on the video, 'topic_comment' — comment in the discussion
        :param item_id: Object ID.
        :param user_id: User ID.
        :param owner_id: ID of the user or community that owns the object.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("likes.isLiked", params)
        model = IsLikedResponse
        return model(**response).response


__all__ = ("LikesCategory",)



import inspect
import typing

from vkbottle_types.objects import (
    DonutDonatorSubscriptionInfo,
    GroupsGroupFull,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class GetSubscriptionResponse(BaseResponse):
    response: DonutDonatorSubscriptionInfo


class GetSubscriptionsResponse(BaseResponse):
    response: "GetSubscriptionsResponseModel"


class GetSubscriptionsResponseModel(BaseResponse):
    subscriptions: typing.Optional[typing.List["DonutDonatorSubscriptionInfo"]] = None
    count: typing.Optional[int] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "DonutDonatorSubscriptionInfo",
    "GetSubscriptionResponse",
    "GetSubscriptionsResponse",
    "GetSubscriptionsResponseModel",
    "GroupsGroupFull",
    "UsersUserFull",
)



import inspect
import typing

from vkbottle_types.objects import (
    BaseBoolInt,
    GroupsGroupFull,
    MarketMarketAlbum,
    MarketMarketCategory,
    MarketMarketCategoryTree,
    MarketMarketItem,
    MarketMarketItemFull,
    MarketOrder,
    MarketOrderItem,
    MarketServicesViewType,
    WallWallComment,
)
from vkbottle_types.responses.base_response import BaseResponse


class AddAlbumResponse(BaseResponse):
    response: "AddAlbumResponseModel"


class AddResponse(BaseResponse):
    response: "AddResponseModel"


class CreateCommentResponse(BaseResponse):
    response: int


class DeleteCommentResponse(BaseResponse):
    response: BaseBoolInt


class GetAlbumByIdResponse(BaseResponse):
    response: "GetAlbumByIdResponseModel"


class GetAlbumsResponse(BaseResponse):
    response: "GetAlbumsResponseModel"


class GetByIdExtendedResponse(BaseResponse):
    response: "GetByIdExtendedResponseModel"


class GetByIdResponse(BaseResponse):
    response: "GetByIdResponseModel"


class GetCategoriesNewResponse(BaseResponse):
    response: "GetCategoriesNewResponseModel"


class GetCategoriesResponse(BaseResponse):
    response: "GetCategoriesResponseModel"


class GetCommentsResponse(BaseResponse):
    response: "GetCommentsResponseModel"


class GetGroupOrdersResponse(BaseResponse):
    response: "GetGroupOrdersResponseModel"


class GetOrderByIdResponse(BaseResponse):
    response: "GetOrderByIdResponseModel"


class GetOrderItemsResponse(BaseResponse):
    response: "GetOrderItemsResponseModel"


class GetOrdersExtendedResponse(BaseResponse):
    response: "GetOrdersExtendedResponseModel"


class GetOrdersResponse(BaseResponse):
    response: "GetOrdersResponseModel"


class GetExtendedResponse(BaseResponse):
    response: "GetExtendedResponseModel"


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class RestoreCommentResponse(BaseResponse):
    response: BaseBoolInt


class SearchExtendedResponse(BaseResponse):
    response: "SearchExtendedResponseModel"


class SearchResponse(BaseResponse):
    response: "SearchResponseModel"


class AddAlbumResponseModel(BaseResponse):
    market_album_id: typing.Optional[int] = None
    albums_count: typing.Optional[int] = None


class AddResponseModel(BaseResponse):
    market_item_id: typing.Optional[int] = None


class GetAlbumByIdResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MarketMarketAlbum"]] = None


class GetAlbumsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MarketMarketAlbum"]] = None


class GetByIdExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MarketMarketItemFull"]] = None


class GetByIdResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MarketMarketItem"]] = None


class GetCategoriesNewResponseModel(BaseResponse):
    items: typing.Optional[typing.List["MarketMarketCategoryTree"]] = None


class GetCategoriesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MarketMarketCategory"]] = None


class GetCommentsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallComment"]] = None


class GetGroupOrdersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MarketOrder"]] = None


class GetOrderByIdResponseModel(BaseResponse):
    order: typing.Optional["MarketOrder"] = None


class GetOrderItemsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MarketOrderItem"]] = None


class GetOrdersExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MarketOrder"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetOrdersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MarketOrder"]] = None


class GetExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MarketMarketItemFull"]] = None
    variants: typing.Optional[typing.List["MarketMarketItemFull"]] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MarketMarketItem"]] = None
    variants: typing.Optional[typing.List["MarketMarketItem"]] = None


class SearchExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    view_type: typing.Optional["MarketServicesViewType"] = None
    items: typing.Optional[typing.List["MarketMarketItemFull"]] = None
    variants: typing.Optional[typing.List["MarketMarketItemFull"]] = None


class SearchResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    view_type: typing.Optional["MarketServicesViewType"] = None
    items: typing.Optional[typing.List["MarketMarketItem"]] = None
    variants: typing.Optional[typing.List["MarketMarketItem"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AddAlbumResponse",
    "AddAlbumResponseModel",
    "AddResponse",
    "AddResponseModel",
    "BaseBoolInt",
    "CreateCommentResponse",
    "DeleteCommentResponse",
    "GetAlbumByIdResponse",
    "GetAlbumByIdResponseModel",
    "GetAlbumsResponse",
    "GetAlbumsResponseModel",
    "GetByIdExtendedResponse",
    "GetByIdExtendedResponseModel",
    "GetByIdResponse",
    "GetByIdResponseModel",
    "GetCategoriesNewResponse",
    "GetCategoriesNewResponseModel",
    "GetCategoriesResponse",
    "GetCategoriesResponseModel",
    "GetCommentsResponse",
    "GetCommentsResponseModel",
    "GetExtendedResponse",
    "GetExtendedResponseModel",
    "GetGroupOrdersResponse",
    "GetGroupOrdersResponseModel",
    "GetOrderByIdResponse",
    "GetOrderByIdResponseModel",
    "GetOrderItemsResponse",
    "GetOrderItemsResponseModel",
    "GetOrdersExtendedResponse",
    "GetOrdersExtendedResponseModel",
    "GetOrdersResponse",
    "GetOrdersResponseModel",
    "GetResponse",
    "GetResponseModel",
    "GroupsGroupFull",
    "MarketMarketAlbum",
    "MarketMarketCategory",
    "MarketMarketCategoryTree",
    "MarketMarketItem",
    "MarketMarketItemFull",
    "MarketOrder",
    "MarketOrderItem",
    "MarketServicesViewType",
    "RestoreCommentResponse",
    "SearchExtendedResponse",
    "SearchExtendedResponseModel",
    "SearchResponse",
    "SearchResponseModel",
    "WallWallComment",
)



import inspect
import typing

from vkbottle_types.objects import (
    GroupsGroupFull,
    NewsfeedList,
    NewsfeedListFull,
    NewsfeedNewsfeedItem,
    UsersSubscriptionsItem,
    UsersUserFull,
    WallWallpostFull,
    WallWallpostToId,
)
from vkbottle_types.responses.base_response import BaseResponse


class GenericResponse(BaseResponse):
    response: "GenericResponseModel"


class GetBannedExtendedResponse(BaseResponse):
    response: "GetBannedExtendedResponseModel"


class GetBannedResponse(BaseResponse):
    response: "GetBannedResponseModel"


class GetCommentsResponse(BaseResponse):
    response: "GetCommentsResponseModel"


class GetListsExtendedResponse(BaseResponse):
    response: "GetListsExtendedResponseModel"


class GetListsResponse(BaseResponse):
    response: "GetListsResponseModel"


class GetMentionsResponse(BaseResponse):
    response: "GetMentionsResponseModel"


class GetSuggestedSourcesResponse(BaseResponse):
    response: "GetSuggestedSourcesResponseModel"


class IgnoreItemResponse(BaseResponse):
    response: "IgnoreItemResponseModel"


class SaveListResponse(BaseResponse):
    response: int


class SearchExtendedResponse(BaseResponse):
    response: "SearchExtendedResponseModel"


class SearchResponse(BaseResponse):
    response: "SearchResponseModel"


class GenericResponseModel(BaseResponse):
    items: typing.Optional[typing.List["NewsfeedNewsfeedItem"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
    new_returned_news_items_count: typing.Optional[int] = None


class GetBannedExtendedResponseModel(BaseResponse):
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetBannedResponseModel(BaseResponse):
    groups: typing.Optional[typing.List[int]] = None
    members: typing.Optional[typing.List[int]] = None


class GetCommentsResponseModel(BaseResponse):
    items: typing.Optional[typing.List["NewsfeedNewsfeedItem"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
    next_from: typing.Optional[str] = None


class GetListsExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["NewsfeedListFull"]] = None


class GetListsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["NewsfeedList"]] = None


class GetMentionsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallpostToId"]] = None


class GetSuggestedSourcesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersSubscriptionsItem"]] = None


class IgnoreItemResponseModel(BaseResponse):
    status: typing.Optional[bool] = None


class SearchExtendedResponseModel(BaseResponse):
    items: typing.Optional[typing.List["WallWallpostFull"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
    suggested_queries: typing.Optional[typing.List[str]] = None
    next_from: typing.Optional[str] = None
    count: typing.Optional[int] = None
    total_count: typing.Optional[int] = None


class SearchResponseModel(BaseResponse):
    items: typing.Optional[typing.List["WallWallpostFull"]] = None
    suggested_queries: typing.Optional[typing.List[str]] = None
    next_from: typing.Optional[str] = None
    count: typing.Optional[int] = None
    total_count: typing.Optional[int] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "GenericResponse",
    "GenericResponseModel",
    "GetBannedExtendedResponse",
    "GetBannedExtendedResponseModel",
    "GetBannedResponse",
    "GetBannedResponseModel",
    "GetCommentsResponse",
    "GetCommentsResponseModel",
    "GetListsExtendedResponse",
    "GetListsExtendedResponseModel",
    "GetListsResponse",
    "GetListsResponseModel",
    "GetMentionsResponse",
    "GetMentionsResponseModel",
    "GetSuggestedSourcesResponse",
    "GetSuggestedSourcesResponseModel",
    "GroupsGroupFull",
    "IgnoreItemResponse",
    "IgnoreItemResponseModel",
    "NewsfeedList",
    "NewsfeedListFull",
    "NewsfeedNewsfeedItem",
    "SaveListResponse",
    "SearchExtendedResponse",
    "SearchExtendedResponseModel",
    "SearchResponse",
    "SearchResponseModel",
    "UsersSubscriptionsItem",
    "UsersUserFull",
    "WallWallpostFull",
    "WallWallpostToId",
)



import inspect
import typing

from vkbottle_types.objects import (
    AppsApp,
    BaseBoolInt,
    GroupsGroup,
    NotificationsNotificationItem,
    NotificationsSendMessageItem,
    PhotosPhoto,
    UsersUser,
    VideoVideo,
)
from vkbottle_types.responses.base_response import BaseResponse


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class MarkAsViewedResponse(BaseResponse):
    response: BaseBoolInt


class SendMessageResponse(BaseResponse):
    response: typing.List["NotificationsSendMessageItem"]


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["NotificationsNotificationItem"]] = None
    profiles: typing.Optional[typing.List["UsersUser"]] = None
    groups: typing.Optional[typing.List["GroupsGroup"]] = None
    last_viewed: typing.Optional[int] = None
    photos: typing.Optional[typing.List["PhotosPhoto"]] = None
    videos: typing.Optional[typing.List["VideoVideo"]] = None
    apps: typing.Optional[typing.List["AppsApp"]] = None
    next_from: typing.Optional[str] = None
    ttl: typing.Optional[int] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AppsApp",
    "BaseBoolInt",
    "GetResponse",
    "GetResponseModel",
    "GroupsGroup",
    "MarkAsViewedResponse",
    "NotificationsNotificationItem",
    "NotificationsSendMessageItem",
    "PhotosPhoto",
    "SendMessageResponse",
    "UsersUser",
    "VideoVideo",
)



import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import BaseBoolInt, OkResponse
from vkbottle_types.responses.messages import (
    CreateChatResponse,
    DeleteChatPhotoResponse,
    DeleteChatPhotoResponseModel,
    DeleteConversationResponse,
    DeleteConversationResponseModel,
    DeleteResponse,
    EditResponse,
    GetByConversationMessageIdExtendedResponse,
    GetByConversationMessageIdExtendedResponseModel,
    GetByConversationMessageIdResponse,
    GetByConversationMessageIdResponseModel,
    GetByIdExtendedResponse,
    GetByIdExtendedResponseModel,
    GetByIdResponse,
    GetByIdResponseModel,
    GetChatPreviewResponse,
    GetChatPreviewResponseModel,
    GetConversationMembersResponse,
    GetConversationsByIdExtendedResponse,
    GetConversationsByIdResponse,
    GetConversationsResponse,
    GetConversationsResponseModel,
    GetHistoryAttachmentsResponse,
    GetHistoryAttachmentsResponseModel,
    GetHistoryExtendedResponse,
    GetHistoryExtendedResponseModel,
    GetHistoryResponse,
    GetHistoryResponseModel,
    GetImportantMessagesExtendedResponse,
    GetImportantMessagesExtendedResponseModel,
    GetImportantMessagesResponse,
    GetImportantMessagesResponseModel,
    GetIntentUsersResponse,
    GetIntentUsersResponseModel,
    GetInviteLinkResponse,
    GetInviteLinkResponseModel,
    GetLastActivityResponse,
    GetLongPollHistoryResponse,
    GetLongPollHistoryResponseModel,
    GetLongPollServerResponse,
    IsMessagesFromGroupAllowedResponse,
    IsMessagesFromGroupAllowedResponseModel,
    JoinChatByInviteLinkResponse,
    JoinChatByInviteLinkResponseModel,
    MarkAsImportantResponse,
    MessagesGetConversationById,
    MessagesGetConversationByIdExtended,
    MessagesGetConversationMembers,
    MessagesLastActivity,
    MessagesLongpollParams,
    MessagesPinnedMessage,
    MessagesSendUserIdsResponseItem,
    PinResponse,
    SearchConversationsExtendedResponse,
    SearchConversationsExtendedResponseModel,
    SearchConversationsResponse,
    SearchConversationsResponseModel,
    SearchExtendedResponse,
    SearchExtendedResponseModel,
    SearchResponse,
    SearchResponseModel,
    SendResponse,
    SendUserIdsResponse,
    SetChatPhotoResponse,
    SetChatPhotoResponseModel,
)


class MessagesCategory(BaseCategory):
    async def add_chat_user(
        self,
        chat_id: int,
        user_id: typing.Optional[int] = None,
        visible_messages_count: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Adds a new user to a chat.

        :param chat_id: Chat ID.
        :param user_id: ID of the user to be added to the chat.
        :param visible_messages_count:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.addChatUser", params)
        model = OkResponse
        return model(**response).response

    async def allow_messages_from_group(
        self, group_id: int, key: typing.Optional[str] = None, **kwargs
    ) -> int:
        """Allows sending messages from community to the current user.

        :param group_id: Group ID.
        :param key:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.allowMessagesFromGroup", params)
        model = OkResponse
        return model(**response).response

    async def create_chat(
        self,
        user_ids: typing.Optional[typing.List[int]] = None,
        title: typing.Optional[str] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Creates a chat with several participants.

        :param user_ids: IDs of the users to be added to the chat.
        :param title: Chat title.
        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.createChat", params)
        model = CreateChatResponse
        return model(**response).response

    async def delete(
        self,
        message_ids: typing.Optional[typing.List[int]] = None,
        spam: typing.Optional[bool] = None,
        group_id: typing.Optional[int] = None,
        delete_for_all: typing.Optional[bool] = None,
        peer_id: typing.Optional[int] = None,
        cmids: typing.Optional[typing.List[int]] = None,
        **kwargs
    ) -> typing.Dict[str, int]:
        """Deletes one or more messages.

        :param message_ids: Message IDs.
        :param spam: '1' — to mark message as spam.
        :param group_id: Group ID (for group messages with user access token)
        :param delete_for_all: '1' — delete message for for all.
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
        :param cmids: Conversation message IDs.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.delete", params)
        model = DeleteResponse
        return model(**response).response

    async def delete_chat_photo(
        self, chat_id: int, group_id: typing.Optional[int] = None, **kwargs
    ) -> DeleteChatPhotoResponseModel:
        """Deletes a chat's cover picture.

        :param chat_id: Chat ID.
        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.deleteChatPhoto", params)
        model = DeleteChatPhotoResponse
        return model(**response).response

    async def delete_conversation(
        self,
        user_id: typing.Optional[int] = None,
        peer_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> DeleteConversationResponseModel:
        """Deletes all private messages in a conversation.

        :param user_id: User ID. To clear a chat history use 'chat_id'
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
        :param group_id: Group ID (for group messages with user access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.deleteConversation", params)
        model = DeleteConversationResponse
        return model(**response).response

    async def deny_messages_from_group(self, group_id: int, **kwargs) -> int:
        """Denies sending message from community to the current user.

        :param group_id: Group ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.denyMessagesFromGroup", params)
        model = OkResponse
        return model(**response).response

    async def edit(
        self,
        peer_id: int,
        message: typing.Optional[str] = None,
        lat: typing.Optional[float] = None,
        long: typing.Optional[float] = None,
        attachment: typing.Optional[str] = None,
        keep_forward_messages: typing.Optional[bool] = None,
        keep_snippets: typing.Optional[bool] = None,
        group_id: typing.Optional[int] = None,
        dont_parse_links: typing.Optional[bool] = None,
        disable_mentions: typing.Optional[bool] = None,
        message_id: typing.Optional[int] = None,
        conversation_message_id: typing.Optional[int] = None,
        template: typing.Optional[str] = None,
        keyboard: typing.Optional[str] = None,
        **kwargs
    ) -> BaseBoolInt:
        """Edits the message.

        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
        :param message: (Required if 'attachments' is not set.) Text of the message.
        :param lat: Geographical latitude of a check-in, in degrees (from -90 to 90).
        :param long: Geographical longitude of a check-in, in degrees (from -180 to 180).
        :param attachment: (Required if 'message' is not set.) List of objects attached to the message, separated by commas, in the following format: "<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, 'wall' — wall post, '<owner_id>' — ID of the media attachment owner. '<media_id>' — media attachment ID. Example: "photo100172_166443618"
        :param keep_forward_messages: '1' — to keep forwarded, messages.
        :param keep_snippets: '1' — to keep attached snippets.
        :param group_id: Group ID (for group messages with user access token)
        :param dont_parse_links:
        :param disable_mentions:
        :param message_id:
        :param conversation_message_id:
        :param template:
        :param keyboard:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.edit", params)
        model = EditResponse
        return model(**response).response

    async def edit_chat(
        self, chat_id: int, title: typing.Optional[str] = None, **kwargs
    ) -> int:
        """Edits the title of a chat.

        :param chat_id: Chat ID.
        :param title: New title of the chat.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.editChat", params)
        model = OkResponse
        return model(**response).response

    @typing.overload
    async def get_by_conversation_message_id(
        self,
        peer_id: int,
        conversation_message_ids: typing.List[int],
        extended: typing.Optional[Literal[False]] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> GetByConversationMessageIdResponseModel:
        ...

    @typing.overload
    async def get_by_conversation_message_id(
        self,
        peer_id: int,
        conversation_message_ids: typing.List[int],
        extended: Literal[True] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> GetByConversationMessageIdExtendedResponseModel:
        ...

    async def get_by_conversation_message_id(
        self,
        peer_id=None,
        conversation_message_ids=None,
        extended=None,
        fields=None,
        group_id=None,
        **kwargs
    ) -> typing.Union[
        GetByConversationMessageIdResponseModel,
        GetByConversationMessageIdExtendedResponseModel,
    ]:
        """Returns messages by their IDs within the conversation.

        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
        :param conversation_message_ids: Conversation message IDs.
        :param extended: Information whether the response should be extended
        :param fields: Profile fields to return.
        :param group_id: Group ID (for group messages with group access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getByConversationMessageId", params)
        model = self.get_model(
            ((("extended",), GetByConversationMessageIdExtendedResponse),),
            default=GetByConversationMessageIdResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def get_by_id(
        self,
        message_ids: typing.List[int],
        preview_length: typing.Optional[int] = None,
        extended: typing.Optional[Literal[False]] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> GetByIdResponseModel:
        ...

    @typing.overload
    async def get_by_id(
        self,
        message_ids: typing.List[int],
        preview_length: typing.Optional[int] = None,
        extended: Literal[True] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> GetByIdExtendedResponseModel:
        ...

    async def get_by_id(
        self,
        message_ids=None,
        preview_length=None,
        extended=None,
        fields=None,
        group_id=None,
        **kwargs
    ) -> typing.Union[GetByIdResponseModel, GetByIdExtendedResponseModel]:
        """Returns messages by their IDs.

        :param message_ids: Message IDs.
        :param preview_length: Number of characters after which to truncate a previewed message. To preview the full message, specify '0'. "NOTE: Messages are not truncated by default. Messages are truncated by words."
        :param extended: Information whether the response should be extended
        :param fields: Profile fields to return.
        :param group_id: Group ID (for group messages with group access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getById", params)
        model = self.get_model(
            ((("extended",), GetByIdExtendedResponse),),
            default=GetByIdResponse,
            params=params,
        )
        return model(**response).response

    async def get_chat_preview(
        self,
        peer_id: typing.Optional[int] = None,
        link: typing.Optional[str] = None,
        fields: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> GetChatPreviewResponseModel:
        """messages.getChatPreview method

        :param peer_id:
        :param link: Invitation link.
        :param fields: Profile fields to return.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getChatPreview", params)
        model = GetChatPreviewResponse
        return model(**response).response

    async def get_conversation_members(
        self,
        peer_id: int,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> MessagesGetConversationMembers:
        """Returns a list of IDs of users participating in a chat.

        :param peer_id: Peer ID.
        :param fields: Profile fields to return.
        :param group_id: Group ID (for group messages with group access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getConversationMembers", params)
        model = GetConversationMembersResponse
        return model(**response).response

    async def get_conversations(
        self,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        filter: typing.Optional[
            Literal["all", "archive", "important", "unanswered", "unread"]
        ] = None,
        extended: typing.Optional[bool] = None,
        start_message_id: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> GetConversationsResponseModel:
        """Returns a list of the current user's conversations.

        :param offset: Offset needed to return a specific subset of conversations.
        :param count: Number of conversations to return.
        :param filter: Filter to apply: 'all' — all conversations, 'unread' — conversations with unread messages, 'important' — conversations, marked as important (only for community messages), 'unanswered' — conversations, marked as unanswered (only for community messages)
        :param extended: '1' — return extra information about users and communities
        :param start_message_id: ID of the message from what to return dialogs.
        :param fields: Profile and communities fields to return.
        :param group_id: Group ID (for group messages with group access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getConversations", params)
        model = GetConversationsResponse
        return model(**response).response

    @typing.overload
    async def get_conversations_by_id(
        self,
        peer_ids: typing.List[int],
        extended: typing.Optional[Literal[False]] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> MessagesGetConversationById:
        ...

    @typing.overload
    async def get_conversations_by_id(
        self,
        peer_ids: typing.List[int],
        extended: Literal[True] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> MessagesGetConversationByIdExtended:
        ...

    async def get_conversations_by_id(
        self, peer_ids=None, extended=None, fields=None, group_id=None, **kwargs
    ) -> typing.Union[MessagesGetConversationById, MessagesGetConversationByIdExtended]:
        """Returns conversations by their IDs

        :param peer_ids: Destination IDs. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
        :param extended: Return extended properties
        :param fields: Profile and communities fields to return.
        :param group_id: Group ID (for group messages with group access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getConversationsById", params)
        model = self.get_model(
            ((("extended",), GetConversationsByIdExtendedResponse),),
            default=GetConversationsByIdResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def get_history(
        self,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        peer_id: typing.Optional[int] = None,
        start_message_id: typing.Optional[int] = None,
        rev: typing.Optional[Literal[1, 0]] = None,
        extended: typing.Optional[Literal[False]] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> GetHistoryResponseModel:
        ...

    @typing.overload
    async def get_history(
        self,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        peer_id: typing.Optional[int] = None,
        start_message_id: typing.Optional[int] = None,
        rev: typing.Optional[Literal[1, 0]] = None,
        extended: Literal[True] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> GetHistoryExtendedResponseModel:
        ...

    async def get_history(
        self,
        offset=None,
        count=None,
        user_id=None,
        peer_id=None,
        start_message_id=None,
        rev=None,
        extended=None,
        fields=None,
        group_id=None,
        **kwargs
    ) -> typing.Union[GetHistoryResponseModel, GetHistoryExtendedResponseModel]:
        """Returns message history for the specified user or group chat.

        :param offset: Offset needed to return a specific subset of messages.
        :param count: Number of messages to return.
        :param user_id: ID of the user whose message history you want to return.
        :param peer_id:
        :param start_message_id: Starting message ID from which to return history.
        :param rev: Sort order: '1' — return messages in chronological order. '0' — return messages in reverse chronological order.
        :param extended: Information whether the response should be extended
        :param fields: Profile fields to return.
        :param group_id: Group ID (for group messages with group access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getHistory", params)
        model = self.get_model(
            ((("extended",), GetHistoryExtendedResponse),),
            default=GetHistoryResponse,
            params=params,
        )
        return model(**response).response

    async def get_history_attachments(
        self,
        peer_id: int,
        media_type: typing.Optional[
            Literal[
                "audio",
                "audio_message",
                "doc",
                "graffiti",
                "link",
                "market",
                "photo",
                "share",
                "video",
                "wall",
            ]
        ] = None,
        start_from: typing.Optional[str] = None,
        count: typing.Optional[int] = None,
        photo_sizes: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        preserve_order: typing.Optional[bool] = None,
        max_forwards_level: typing.Optional[int] = None,
        **kwargs
    ) -> GetHistoryAttachmentsResponseModel:
        """Returns media files from the dialog or group chat.

        :param peer_id: Peer ID. ", For group chat: '2000000000 + chat ID' , , For community: '-community ID'"
        :param media_type: Type of media files to return: *'photo',, *'video',, *'audio',, *'doc',, *'link'.,*'market'.,*'wall'.,*'share'
        :param start_from: Message ID to start return results from.
        :param count: Number of objects to return.
        :param photo_sizes: '1' — to return photo sizes in a
        :param fields: Additional profile [vk.com/dev/fields|fields] to return.
        :param group_id: Group ID (for group messages with group access token)
        :param preserve_order:
        :param max_forwards_level:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getHistoryAttachments", params)
        model = GetHistoryAttachmentsResponse
        return model(**response).response

    @typing.overload
    async def get_important_messages(
        self,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        start_message_id: typing.Optional[int] = None,
        preview_length: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        extended: typing.Optional[Literal[False]] = ...,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> GetImportantMessagesResponseModel:
        ...

    @typing.overload
    async def get_important_messages(
        self,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        start_message_id: typing.Optional[int] = None,
        preview_length: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        extended: Literal[True] = ...,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> GetImportantMessagesExtendedResponseModel:
        ...

    async def get_important_messages(
        self,
        count=None,
        offset=None,
        start_message_id=None,
        preview_length=None,
        fields=None,
        extended=None,
        group_id=None,
        **kwargs
    ) -> typing.Union[
        GetImportantMessagesResponseModel, GetImportantMessagesExtendedResponseModel
    ]:
        """Returns a list of user's important messages.

        :param count: Amount of needed important messages.
        :param offset:
        :param start_message_id:
        :param preview_length: Maximum length of messages body.
        :param fields: Actors fields to return.
        :param extended: Return extended properties
        :param group_id: Group ID (for group messages with group access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getImportantMessages", params)
        model = self.get_model(
            ((("extended",), GetImportantMessagesExtendedResponse),),
            default=GetImportantMessagesResponse,
            params=params,
        )
        return model(**response).response

    async def get_intent_users(
        self,
        intent: Literal[
            "confirmed_notification", "non_promo_newsletter", "promo_newsletter"
        ],
        subscribe_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: typing.Optional[bool] = None,
        name_case: typing.Optional[typing.List[str]] = None,
        fields: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> GetIntentUsersResponseModel:
        """messages.getIntentUsers method

        :param intent:
        :param subscribe_id:
        :param offset:
        :param count:
        :param extended:
        :param name_case:
        :param fields:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getIntentUsers", params)
        model = GetIntentUsersResponse
        return model(**response).response

    async def get_invite_link(
        self,
        peer_id: int,
        reset: typing.Optional[bool] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> GetInviteLinkResponseModel:
        """messages.getInviteLink method

        :param peer_id: Destination ID.
        :param reset: 1 — to generate new link (revoke previous), 0 — to return previous link.
        :param group_id: Group ID
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getInviteLink", params)
        model = GetInviteLinkResponse
        return model(**response).response

    async def get_last_activity(self, user_id: int, **kwargs) -> MessagesLastActivity:
        """Returns a user's current status and date of last activity.

        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getLastActivity", params)
        model = GetLastActivityResponse
        return model(**response).response

    async def get_long_poll_history(
        self,
        ts: typing.Optional[int] = None,
        pts: typing.Optional[int] = None,
        preview_length: typing.Optional[int] = None,
        onlines: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[str]] = None,
        events_limit: typing.Optional[int] = None,
        msgs_limit: typing.Optional[int] = None,
        max_msg_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        lp_version: typing.Optional[int] = None,
        last_n: typing.Optional[int] = None,
        credentials: typing.Optional[bool] = None,
        extended: typing.Optional[bool] = None,
        **kwargs
    ) -> GetLongPollHistoryResponseModel:
        """Returns updates in user's private messages.

        :param ts: Last value of the 'ts' parameter returned from the Long Poll server or by using [vk.com/dev/messages.getLongPollHistory|messages.getLongPollHistory] method.
        :param pts: Last value of 'pts' parameter returned from the Long Poll server or by using [vk.com/dev/messages.getLongPollHistory|messages.getLongPollHistory] method.
        :param preview_length: Number of characters after which to truncate a previewed message. To preview the full message, specify '0'. "NOTE: Messages are not truncated by default. Messages are truncated by words."
        :param onlines: '1' — to return history with online users only.
        :param fields: Additional profile [vk.com/dev/fields|fields] to return.
        :param events_limit: Maximum number of events to return.
        :param msgs_limit: Maximum number of messages to return.
        :param max_msg_id: Maximum ID of the message among existing ones in the local copy. Both messages received with API methods (for example, , ), and data received from a Long Poll server (events with code 4) are taken into account.
        :param group_id: Group ID (for group messages with user access token)
        :param lp_version:
        :param last_n:
        :param credentials:
        :param extended:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getLongPollHistory", params)
        model = GetLongPollHistoryResponse
        return model(**response).response

    async def get_long_poll_server(
        self,
        need_pts: typing.Optional[bool] = None,
        group_id: typing.Optional[int] = None,
        lp_version: typing.Optional[int] = None,
        **kwargs
    ) -> MessagesLongpollParams:
        """Returns data required for connection to a Long Poll server.

        :param need_pts: '1' — to return the 'pts' field, needed for the [vk.com/dev/messages.getLongPollHistory|messages.getLongPollHistory] method.
        :param group_id: Group ID (for group messages with user access token)
        :param lp_version: Long poll version
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.getLongPollServer", params)
        model = GetLongPollServerResponse
        return model(**response).response

    async def is_messages_from_group_allowed(
        self, group_id: int, user_id: int, **kwargs
    ) -> IsMessagesFromGroupAllowedResponseModel:
        """Returns information whether sending messages from the community to current user is allowed.

        :param group_id: Group ID.
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.isMessagesFromGroupAllowed", params)
        model = IsMessagesFromGroupAllowedResponse
        return model(**response).response

    async def join_chat_by_invite_link(
        self, link: str, **kwargs
    ) -> JoinChatByInviteLinkResponseModel:
        """messages.joinChatByInviteLink method

        :param link: Invitation link.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.joinChatByInviteLink", params)
        model = JoinChatByInviteLinkResponse
        return model(**response).response

    async def mark_as_answered_conversation(
        self,
        peer_id: int,
        answered: typing.Optional[bool] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Marks and unmarks conversations as unanswered.

        :param peer_id: ID of conversation to mark as important.
        :param answered: '1' — to mark as answered, '0' — to remove the mark
        :param group_id: Group ID (for group messages with group access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.markAsAnsweredConversation", params)
        model = OkResponse
        return model(**response).response

    async def mark_as_important(
        self,
        message_ids: typing.Optional[typing.List[int]] = None,
        important: typing.Optional[int] = None,
        **kwargs
    ) -> typing.List[int]:
        """Marks and unmarks messages as important (starred).

        :param message_ids: IDs of messages to mark as important.
        :param important: '1' — to add a star (mark as important), '0' — to remove the star
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.markAsImportant", params)
        model = MarkAsImportantResponse
        return model(**response).response

    async def mark_as_important_conversation(
        self,
        peer_id: int,
        important: typing.Optional[bool] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Marks and unmarks conversations as important.

        :param peer_id: ID of conversation to mark as important.
        :param important: '1' — to add a star (mark as important), '0' — to remove the star
        :param group_id: Group ID (for group messages with group access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request(
            "messages.markAsImportantConversation", params
        )
        model = OkResponse
        return model(**response).response

    async def mark_as_read(
        self,
        message_ids: typing.Optional[typing.List[int]] = None,
        peer_id: typing.Optional[int] = None,
        start_message_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        mark_conversation_as_read: typing.Optional[bool] = None,
        **kwargs
    ) -> int:
        """Marks messages as read.

        :param message_ids: IDs of messages to mark as read.
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
        :param start_message_id: Message ID to start from.
        :param group_id: Group ID (for group messages with user access token)
        :param mark_conversation_as_read:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.markAsRead", params)
        model = OkResponse
        return model(**response).response

    async def pin(
        self,
        peer_id: int,
        message_id: typing.Optional[int] = None,
        conversation_message_id: typing.Optional[int] = None,
        **kwargs
    ) -> MessagesPinnedMessage:
        """Pin a message.

        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
        :param message_id: Message ID
        :param conversation_message_id: Conversation message ID
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.pin", params)
        model = PinResponse
        return model(**response).response

    async def remove_chat_user(
        self,
        chat_id: int,
        user_id: typing.Optional[int] = None,
        member_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Allows the current user to leave a chat or, if the current user started the chat, allows the user to remove another user from the chat.

        :param chat_id: Chat ID.
        :param user_id: ID of the user to be removed from the chat.
        :param member_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.removeChatUser", params)
        model = OkResponse
        return model(**response).response

    async def restore(
        self, message_id: int, group_id: typing.Optional[int] = None, **kwargs
    ) -> int:
        """Restores a deleted message.

        :param message_id: ID of a previously-deleted message to restore.
        :param group_id: Group ID (for group messages with user access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.restore", params)
        model = OkResponse
        return model(**response).response

    @typing.overload
    async def search(
        self,
        q: typing.Optional[str] = None,
        peer_id: typing.Optional[int] = None,
        date: typing.Optional[int] = None,
        preview_length: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: typing.Optional[Literal[False]] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> SearchResponseModel:
        ...

    @typing.overload
    async def search(
        self,
        q: typing.Optional[str] = None,
        peer_id: typing.Optional[int] = None,
        date: typing.Optional[int] = None,
        preview_length: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: Literal[True] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> SearchExtendedResponseModel:
        ...

    async def search(
        self,
        q=None,
        peer_id=None,
        date=None,
        preview_length=None,
        offset=None,
        count=None,
        extended=None,
        fields=None,
        group_id=None,
        **kwargs
    ) -> typing.Union[SearchResponseModel, SearchExtendedResponseModel]:
        """Returns a list of the current user's private messages that match search criteria.

        :param q: Search query string.
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
        :param date: Date to search message before in Unixtime.
        :param preview_length: Number of characters after which to truncate a previewed message. To preview the full message, specify '0'. "NOTE: Messages are not truncated by default. Messages are truncated by words."
        :param offset: Offset needed to return a specific subset of messages.
        :param count: Number of messages to return.
        :param extended:
        :param fields:
        :param group_id: Group ID (for group messages with group access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.search", params)
        model = self.get_model(
            ((("extended",), SearchExtendedResponse),),
            default=SearchResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def search_conversations(
        self,
        q: typing.Optional[str] = None,
        count: typing.Optional[int] = None,
        extended: typing.Optional[Literal[False]] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> SearchConversationsResponseModel:
        ...

    @typing.overload
    async def search_conversations(
        self,
        q: typing.Optional[str] = None,
        count: typing.Optional[int] = None,
        extended: Literal[True] = ...,
        fields: typing.Optional[typing.List[str]] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> SearchConversationsExtendedResponseModel:
        ...

    async def search_conversations(
        self, q=None, count=None, extended=None, fields=None, group_id=None, **kwargs
    ) -> typing.Union[
        SearchConversationsResponseModel, SearchConversationsExtendedResponseModel
    ]:
        """Returns a list of the current user's conversations that match search criteria.

        :param q: Search query string.
        :param count: Maximum number of results.
        :param extended: '1' — return extra information about users and communities
        :param fields: Profile fields to return.
        :param group_id: Group ID (for group messages with user access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.searchConversations", params)
        model = self.get_model(
            ((("extended",), SearchConversationsExtendedResponse),),
            default=SearchConversationsResponse,
            params=params,
        )
        return model(**response).response

    @typing.overload
    async def send(
        self,
        user_id: typing.Optional[int] = None,
        random_id: typing.Optional[int] = None,
        peer_id: typing.Optional[int] = None,
        peer_ids: typing.Optional[typing.List[int]] = None,
        domain: typing.Optional[str] = None,
        chat_id: typing.Optional[int] = None,
        user_ids: typing.Optional[Literal[None]] = ...,
        message: typing.Optional[str] = None,
        lat: typing.Optional[float] = None,
        long: typing.Optional[float] = None,
        attachment: typing.Optional[str] = None,
        reply_to: typing.Optional[int] = None,
        forward_messages: typing.Optional[typing.List[int]] = None,
        forward: typing.Optional[str] = None,
        sticker_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        keyboard: typing.Optional[str] = None,
        template: typing.Optional[str] = None,
        payload: typing.Optional[str] = None,
        content_source: typing.Optional[str] = None,
        dont_parse_links: typing.Optional[bool] = None,
        disable_mentions: typing.Optional[bool] = None,
        intent: typing.Optional[
            Literal[
                "account_update",
                "bot_ad_invite",
                "bot_ad_promo",
                "confirmed_notification",
                "customer_support",
                "default",
                "game_notification",
                "moderated_newsletter",
                "non_promo_newsletter",
                "promo_newsletter",
                "purchase_update",
            ]
        ] = None,
        subscribe_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        ...

    @typing.overload
    async def send(
        self,
        user_id: typing.Optional[int] = None,
        random_id: typing.Optional[int] = None,
        peer_id: typing.Optional[int] = None,
        peer_ids: typing.Optional[typing.List[int]] = None,
        domain: typing.Optional[str] = None,
        chat_id: typing.Optional[int] = None,
        user_ids: typing.List[int] = ...,
        message: typing.Optional[str] = None,
        lat: typing.Optional[float] = None,
        long: typing.Optional[float] = None,
        attachment: typing.Optional[str] = None,
        reply_to: typing.Optional[int] = None,
        forward_messages: typing.Optional[typing.List[int]] = None,
        forward: typing.Optional[str] = None,
        sticker_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        keyboard: typing.Optional[str] = None,
        template: typing.Optional[str] = None,
        payload: typing.Optional[str] = None,
        content_source: typing.Optional[str] = None,
        dont_parse_links: typing.Optional[bool] = None,
        disable_mentions: typing.Optional[bool] = None,
        intent: typing.Optional[
            Literal[
                "account_update",
                "bot_ad_invite",
                "bot_ad_promo",
                "confirmed_notification",
                "customer_support",
                "default",
                "game_notification",
                "moderated_newsletter",
                "non_promo_newsletter",
                "promo_newsletter",
                "purchase_update",
            ]
        ] = None,
        subscribe_id: typing.Optional[int] = None,
        **kwargs
    ) -> typing.List[MessagesSendUserIdsResponseItem]:
        ...

    async def send(
        self,
        user_id=None,
        random_id=None,
        peer_id=None,
        peer_ids=None,
        domain=None,
        chat_id=None,
        user_ids=None,
        message=None,
        lat=None,
        long=None,
        attachment=None,
        reply_to=None,
        forward_messages=None,
        forward=None,
        sticker_id=None,
        group_id=None,
        keyboard=None,
        template=None,
        payload=None,
        content_source=None,
        dont_parse_links=None,
        disable_mentions=None,
        intent=None,
        subscribe_id=None,
        **kwargs
    ) -> typing.Union[int, typing.List[MessagesSendUserIdsResponseItem]]:
        """Sends a message.

        :param user_id: User ID (by default — current user).
        :param random_id: Unique identifier to avoid resending the message.
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
        :param peer_ids: IDs of message recipients. (See peer_id)
        :param domain: User's short address (for example, 'illarionov').
        :param chat_id: ID of conversation the message will relate to.
        :param user_ids: IDs of message recipients (if new conversation shall be started).
        :param message: (Required if 'attachments' is not set.) Text of the message.
        :param lat: Geographical latitude of a check-in, in degrees (from -90 to 90).
        :param long: Geographical longitude of a check-in, in degrees (from -180 to 180).
        :param attachment: (Required if 'message' is not set.) List of objects attached to the message, separated by commas, in the following format: "<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, 'wall' — wall post, '<owner_id>' — ID of the media attachment owner. '<media_id>' — media attachment ID. Example: "photo100172_166443618"
        :param reply_to:
        :param forward_messages: ID of forwarded messages, separated with a comma. Listed messages of the sender will be shown in the message body at the recipient's. Example: "123,431,544"
        :param forward: JSON describing the forwarded message or reply
        :param sticker_id: Sticker id.
        :param group_id: Group ID (for group messages with group access token)
        :param keyboard:
        :param template:
        :param payload:
        :param content_source: JSON describing the content source in the message
        :param dont_parse_links:
        :param disable_mentions:
        :param intent:
        :param subscribe_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.send", params)
        model = self.get_model(
            ((("user_ids",), SendUserIdsResponse),),
            default=SendResponse,
            params=params,
        )
        return model(**response).response

    async def send_message_event_answer(
        self,
        event_id: str,
        user_id: int,
        peer_id: int,
        event_data: typing.Optional[str] = None,
        **kwargs
    ) -> int:
        """messages.sendMessageEventAnswer method

        :param event_id:
        :param user_id:
        :param peer_id:
        :param event_data:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.sendMessageEventAnswer", params)
        model = OkResponse
        return model(**response).response

    async def set_activity(
        self,
        user_id: typing.Optional[int] = None,
        type: typing.Optional[
            Literal["audiomessage", "file", "photo", "typing", "video"]
        ] = None,
        peer_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Changes the status of a user as typing in a conversation.

        :param user_id: User ID.
        :param type: 'typing' — user has started to type.
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
        :param group_id: Group ID (for group messages with group access token)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.setActivity", params)
        model = OkResponse
        return model(**response).response

    async def set_chat_photo(self, file: str, **kwargs) -> SetChatPhotoResponseModel:
        """Sets a previously-uploaded picture as the cover picture of a chat.

        :param file: Upload URL from the 'response' field returned by the [vk.com/dev/photos.getChatUploadServer|photos.getChatUploadServer] method upon successfully uploading an image.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.setChatPhoto", params)
        model = SetChatPhotoResponse
        return model(**response).response

    async def unpin(
        self, peer_id: int, group_id: typing.Optional[int] = None, **kwargs
    ) -> int:
        """messages.unpin method

        :param peer_id:
        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("messages.unpin", params)
        model = OkResponse
        return model(**response).response


__all__ = ("MessagesCategory",)



from typing import TYPE_CHECKING, Any, Callable, Dict, Type, Union

from .enums import GroupEventType, UserEventType

if TYPE_CHECKING:
    from . import GroupTypes, UserTypes
    from .bot_events import BaseGroupEvent
    from .user_events import BaseUserEvent


class EventsBase:
    events_registered: Dict[
        Union[GroupEventType, UserEventType],
        Type[Union["GroupTypes.UnifiedTypes", "UserTypes.UnifiedTypes"]],
    ] = {}

    def __init__(
        self,
        type_enum: Type[Union[GroupEventType, UserEventType]],
        on_undefined: Callable[[str], Any] = lambda et: EventsBase.__raise(
            NotImplementedError(et)
        ),
    ):
        self.type_enum = type_enum
        self.on_undefined = on_undefined

    def register(
        self,
        event_type: Union[GroupEventType, UserEventType],
        event_model: Union["BaseGroupEvent", "BaseUserEvent"],
    ):
        self.events_registered[event_type] = event_model

    def get(
        self, event_type: Union[int, str, GroupEventType, UserEventType]
    ) -> Callable[..., Union["GroupTypes.UnifiedTypes", "UserTypes.UnifiedTypes"]]:
        if not str(event_type).startswith(self.type_enum.__name__):
            event_type = self.type_enum(event_type)

        model = self.events_registered.get(event_type)
        if model is None:
            return self.on_undefined(event_type)
        return model

    @staticmethod
    def __raise(ex):
        raise ex



from vkbottle_types.responses.base_response import BaseResponse
from vkbottle_types.codegen.responses.secure import *  # noqa: F403,F401


class SetCounterIntegerResponse(BaseResponse):
    response: int


SetCounterIntegerResponse.update_forward_refs()



import inspect
import typing

from vkbottle_types.objects import (
    AccountAccountCounters,
    AccountInfo,
    AccountNameRequest,
    AccountOffer,
    AccountPushSettings,
    AccountUserSettings,
    BaseBoolInt,
    GroupsGroup,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class ChangePasswordResponse(BaseResponse):
    response: "ChangePasswordResponseModel"


class GetActiveOffersResponse(BaseResponse):
    response: "GetActiveOffersResponseModel"


class GetAppPermissionsResponse(BaseResponse):
    response: int


class GetBannedResponse(BaseResponse):
    response: "GetBannedResponseModel"


class GetCountersResponse(BaseResponse):
    response: AccountAccountCounters


class GetInfoResponse(BaseResponse):
    response: AccountInfo


class GetProfileInfoResponse(BaseResponse):
    response: AccountUserSettings


class GetPushSettingsResponse(BaseResponse):
    response: AccountPushSettings


class SaveProfileInfoResponse(BaseResponse):
    response: "SaveProfileInfoResponseModel"


class ChangePasswordResponseModel(BaseResponse):
    token: typing.Optional[str] = None
    secret: typing.Optional[str] = None


class GetActiveOffersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["AccountOffer"]] = None


class GetBannedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroup"]] = None


class SaveProfileInfoResponseModel(BaseResponse):
    changed: typing.Optional["BaseBoolInt"] = None
    name_request: typing.Optional["AccountNameRequest"] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AccountAccountCounters",
    "AccountInfo",
    "AccountNameRequest",
    "AccountOffer",
    "AccountPushSettings",
    "AccountUserSettings",
    "BaseBoolInt",
    "ChangePasswordResponse",
    "ChangePasswordResponseModel",
    "GetActiveOffersResponse",
    "GetActiveOffersResponseModel",
    "GetAppPermissionsResponse",
    "GetBannedResponse",
    "GetBannedResponseModel",
    "GetCountersResponse",
    "GetInfoResponse",
    "GetProfileInfoResponse",
    "GetPushSettingsResponse",
    "GroupsGroup",
    "SaveProfileInfoResponse",
    "SaveProfileInfoResponseModel",
    "UsersUserFull",
)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.adsweb import (
    GetAdCategoriesResponse,
    GetAdCategoriesResponseModel,
    GetAdUnitCodeResponse,
    GetAdUnitCodeResponseModel,
    GetAdUnitsResponse,
    GetAdUnitsResponseModel,
    GetFraudHistoryResponse,
    GetFraudHistoryResponseModel,
    GetSitesResponse,
    GetSitesResponseModel,
    GetStatisticsResponse,
    GetStatisticsResponseModel,
)


class AdswebCategory(BaseCategory):
    async def get_ad_categories(
        self, office_id: int, **kwargs
    ) -> GetAdCategoriesResponseModel:
        """adsweb.getAdCategories method

        :param office_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getAdCategories", params)
        model = GetAdCategoriesResponse
        return model(**response).response

    async def get_ad_unit_code(self, **kwargs) -> GetAdUnitCodeResponseModel:
        """adsweb.getAdUnitCode method"""

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getAdUnitCode", params)
        model = GetAdUnitCodeResponse
        return model(**response).response

    async def get_ad_units(
        self,
        office_id: int,
        sites_ids: typing.Optional[str] = None,
        ad_units_ids: typing.Optional[str] = None,
        fields: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        **kwargs
    ) -> GetAdUnitsResponseModel:
        """adsweb.getAdUnits method

        :param office_id:
        :param sites_ids:
        :param ad_units_ids:
        :param fields:
        :param limit:
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getAdUnits", params)
        model = GetAdUnitsResponse
        return model(**response).response

    async def get_fraud_history(
        self,
        office_id: int,
        sites_ids: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        **kwargs
    ) -> GetFraudHistoryResponseModel:
        """adsweb.getFraudHistory method

        :param office_id:
        :param sites_ids:
        :param limit:
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getFraudHistory", params)
        model = GetFraudHistoryResponse
        return model(**response).response

    async def get_sites(
        self,
        office_id: int,
        sites_ids: typing.Optional[str] = None,
        fields: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        **kwargs
    ) -> GetSitesResponseModel:
        """adsweb.getSites method

        :param office_id:
        :param sites_ids:
        :param fields:
        :param limit:
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getSites", params)
        model = GetSitesResponse
        return model(**response).response

    async def get_statistics(
        self,
        office_id: int,
        ids_type: str,
        ids: str,
        period: str,
        date_from: str,
        date_to: str,
        fields: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        page_id: typing.Optional[str] = None,
        **kwargs
    ) -> GetStatisticsResponseModel:
        """adsweb.getStatistics method

        :param office_id:
        :param ids_type:
        :param ids:
        :param period:
        :param date_from:
        :param date_to:
        :param fields:
        :param limit:
        :param page_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getStatistics", params)
        model = GetStatisticsResponse
        return model(**response).response


__all__ = ("AdswebCategory",)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import BaseBoolInt, BoolResponse, OkResponse
from vkbottle_types.responses.secure import (
    CheckTokenResponse,
    GetAppBalanceResponse,
    GetSMSHistoryResponse,
    GetTransactionsHistoryResponse,
    GetUserLevelResponse,
    GiveEventStickerResponse,
    SecureGiveEventStickerItem,
    SecureLevel,
    SecureSmsNotification,
    SecureTokenChecked,
    SecureTransaction,
    SendNotificationResponse,
)


class SecureCategory(BaseCategory):
    async def add_app_event(
        self,
        user_id: int,
        activity_id: int,
        value: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Adds user activity information to an application

        :param user_id: ID of a user to save the data
        :param activity_id: there are 2 default activities: , * 1 - level. Works similar to ,, * 2 - points, saves points amount, Any other value is for saving completed missions
        :param value: depends on activity_id: * 1 - number, current level number,, * 2 - number, current user's points amount, , Any other value is ignored
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.addAppEvent", params)
        model = OkResponse
        return model(**response).response

    async def check_token(
        self,
        token: typing.Optional[str] = None,
        ip: typing.Optional[str] = None,
        **kwargs
    ) -> SecureTokenChecked:
        """Checks the user authentication in 'IFrame' and 'Flash' apps using the 'access_token' parameter.

        :param token: client 'access_token'
        :param ip: user 'ip address'. Note that user may access using the 'ipv6' address, in this case it is required to transmit the 'ipv6' address. If not transmitted, the address will not be checked.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.checkToken", params)
        model = CheckTokenResponse
        return model(**response).response

    async def get_app_balance(self, **kwargs) -> int:
        """Returns payment balance of the application in hundredth of a vote."""

        params = self.get_set_params(locals())
        response = await self.api.request("secure.getAppBalance", params)
        model = GetAppBalanceResponse
        return model(**response).response

    async def get_sms_history(
        self,
        user_id: typing.Optional[int] = None,
        date_from: typing.Optional[int] = None,
        date_to: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        **kwargs
    ) -> typing.List[SecureSmsNotification]:
        """Shows a list of SMS notifications sent by the application using [vk.com/dev/secure.sendSMSNotification|secure.sendSMSNotification] method.

        :param user_id:
        :param date_from: filter by start date. It is set as UNIX-time.
        :param date_to: filter by end date. It is set as UNIX-time.
        :param limit: number of returned posts. By default — 1000.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.getSMSHistory", params)
        model = GetSMSHistoryResponse
        return model(**response).response

    async def get_transactions_history(
        self,
        type: typing.Optional[int] = None,
        uid_from: typing.Optional[int] = None,
        uid_to: typing.Optional[int] = None,
        date_from: typing.Optional[int] = None,
        date_to: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        **kwargs
    ) -> typing.List[SecureTransaction]:
        """Shows history of votes transaction between users and the application.

        :param type:
        :param uid_from:
        :param uid_to:
        :param date_from:
        :param date_to:
        :param limit:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.getTransactionsHistory", params)
        model = GetTransactionsHistoryResponse
        return model(**response).response

    async def get_user_level(
        self, user_ids: typing.List[int], **kwargs
    ) -> typing.List[SecureLevel]:
        """Returns one of the previously set game levels of one or more users in the application.

        :param user_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.getUserLevel", params)
        model = GetUserLevelResponse
        return model(**response).response

    async def give_event_sticker(
        self, user_ids: typing.List[int], achievement_id: int, **kwargs
    ) -> typing.List[SecureGiveEventStickerItem]:
        """Opens the game achievement and gives the user a sticker

        :param user_ids:
        :param achievement_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.giveEventSticker", params)
        model = GiveEventStickerResponse
        return model(**response).response

    async def send_notification(
        self,
        message: str,
        user_ids: typing.Optional[typing.List[int]] = None,
        user_id: typing.Optional[int] = None,
        **kwargs
    ) -> typing.List[int]:
        """Sends notification to the user.

        :param message: notification text which should be sent in 'UTF-8' encoding ('254' characters maximum).
        :param user_ids:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.sendNotification", params)
        model = SendNotificationResponse
        return model(**response).response

    async def send_sms_notification(self, user_id: int, message: str, **kwargs) -> int:
        """Sends 'SMS' notification to a user's mobile device.

        :param user_id: ID of the user to whom SMS notification is sent. The user shall allow the application to send him/her notifications (, +1).
        :param message: 'SMS' text to be sent in 'UTF-8' encoding. Only Latin letters and numbers are allowed. Maximum size is '160' characters.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.sendSMSNotification", params)
        model = OkResponse
        return model(**response).response

    async def set_counter(
        self,
        counters: typing.Optional[typing.List[str]] = None,
        user_id: typing.Optional[int] = None,
        counter: typing.Optional[int] = None,
        increment: typing.Optional[bool] = None,
        **kwargs
    ) -> BaseBoolInt:
        """Sets a counter which is shown to the user in bold in the left menu.

        :param counters:
        :param user_id:
        :param counter: counter value.
        :param increment:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.setCounter", params)
        model = self.get_model(
            ((("response_integer",), BoolResponse),),
            default=None,
            params=params,
        )
        return model(**response).response


__all__ = ("SecureCategory",)



import inspect
import typing

from vkbottle_types.objects import WidgetsWidgetComment, WidgetsWidgetPage
from vkbottle_types.responses.base_response import BaseResponse


class GetCommentsResponse(BaseResponse):
    response: "GetCommentsResponseModel"


class GetPagesResponse(BaseResponse):
    response: "GetPagesResponseModel"


class GetCommentsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    posts: typing.Optional[typing.List["WidgetsWidgetComment"]] = None


class GetPagesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    pages: typing.Optional[typing.List["WidgetsWidgetPage"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "GetCommentsResponse",
    "GetCommentsResponseModel",
    "GetPagesResponse",
    "GetPagesResponseModel",
    "WidgetsWidgetComment",
    "WidgetsWidgetPage",
)



import inspect
import typing

from vkbottle_types.objects import (
    BaseBoolInt,
    GroupsGroupFull,
    MessagesChat,
    MessagesChatFull,
    MessagesChatPreview,
    MessagesConversation,
    MessagesConversationWithMessage,
    MessagesGetConversationById,
    MessagesGetConversationByIdExtended,
    MessagesGetConversationMembers,
    MessagesHistoryAttachment,
    MessagesLastActivity,
    MessagesLongpollMessages,
    MessagesLongpollParams,
    MessagesMessage,
    MessagesMessagesArray,
    MessagesPinnedMessage,
    MessagesSendUserIdsResponseItem,
    UsersUser,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class CreateChatResponse(BaseResponse):
    response: int


class DeleteChatPhotoResponse(BaseResponse):
    response: "DeleteChatPhotoResponseModel"


class DeleteConversationResponse(BaseResponse):
    response: "DeleteConversationResponseModel"


class DeleteResponse(BaseResponse):
    response: typing.Dict[str, int]


class EditResponse(BaseResponse):
    response: BaseBoolInt


class GetByConversationMessageIdExtendedResponse(BaseResponse):
    response: "GetByConversationMessageIdExtendedResponseModel"


class GetByConversationMessageIdResponse(BaseResponse):
    response: "GetByConversationMessageIdResponseModel"


class GetByIdExtendedResponse(BaseResponse):
    response: "GetByIdExtendedResponseModel"


class GetByIdResponse(BaseResponse):
    response: "GetByIdResponseModel"


class GetChatPreviewResponse(BaseResponse):
    response: "GetChatPreviewResponseModel"


class GetChatChatIdsFieldsResponse(BaseResponse):
    response: typing.List["MessagesChatFull"]


class GetChatChatIdsResponse(BaseResponse):
    response: typing.List["MessagesChat"]


class GetChatFieldsResponse(BaseResponse):
    response: MessagesChatFull


class GetChatResponse(BaseResponse):
    response: MessagesChat


class GetConversationMembersResponse(BaseResponse):
    response: MessagesGetConversationMembers


class GetConversationsByIdExtendedResponse(BaseResponse):
    response: MessagesGetConversationByIdExtended


class GetConversationsByIdResponse(BaseResponse):
    response: MessagesGetConversationById


class GetConversationsResponse(BaseResponse):
    response: "GetConversationsResponseModel"


class GetHistoryAttachmentsResponse(BaseResponse):
    response: "GetHistoryAttachmentsResponseModel"


class GetHistoryExtendedResponse(BaseResponse):
    response: "GetHistoryExtendedResponseModel"


class GetHistoryResponse(BaseResponse):
    response: "GetHistoryResponseModel"


class GetImportantMessagesExtendedResponse(BaseResponse):
    response: "GetImportantMessagesExtendedResponseModel"


class GetImportantMessagesResponse(BaseResponse):
    response: "GetImportantMessagesResponseModel"


class GetIntentUsersResponse(BaseResponse):
    response: "GetIntentUsersResponseModel"


class GetInviteLinkResponse(BaseResponse):
    response: "GetInviteLinkResponseModel"


class GetLastActivityResponse(BaseResponse):
    response: MessagesLastActivity


class GetLongPollHistoryResponse(BaseResponse):
    response: "GetLongPollHistoryResponseModel"


class GetLongPollServerResponse(BaseResponse):
    response: MessagesLongpollParams


class IsMessagesFromGroupAllowedResponse(BaseResponse):
    response: "IsMessagesFromGroupAllowedResponseModel"


class JoinChatByInviteLinkResponse(BaseResponse):
    response: "JoinChatByInviteLinkResponseModel"


class MarkAsImportantResponse(BaseResponse):
    response: typing.List[int]


class PinResponse(BaseResponse):
    response: MessagesPinnedMessage


class SearchConversationsExtendedResponse(BaseResponse):
    response: "SearchConversationsExtendedResponseModel"


class SearchConversationsResponse(BaseResponse):
    response: "SearchConversationsResponseModel"


class SearchExtendedResponse(BaseResponse):
    response: "SearchExtendedResponseModel"


class SearchResponse(BaseResponse):
    response: "SearchResponseModel"


class SendResponse(BaseResponse):
    response: int


class SendUserIdsResponse(BaseResponse):
    response: typing.List["MessagesSendUserIdsResponseItem"]


class SetChatPhotoResponse(BaseResponse):
    response: "SetChatPhotoResponseModel"


class DeleteChatPhotoResponseModel(BaseResponse):
    message_id: typing.Optional[int] = None
    chat: typing.Optional["MessagesChat"] = None


class DeleteConversationResponseModel(BaseResponse):
    last_deleted_id: typing.Optional[int] = None


class GetByConversationMessageIdExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MessagesMessage"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetByConversationMessageIdResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MessagesMessage"]] = None


class GetByIdExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MessagesMessage"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetByIdResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MessagesMessage"]] = None


class GetChatPreviewResponseModel(BaseResponse):
    preview: typing.Optional["MessagesChatPreview"] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetConversationsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    unread_count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MessagesConversationWithMessage"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetHistoryAttachmentsResponseModel(BaseResponse):
    items: typing.Optional[typing.List["MessagesHistoryAttachment"]] = None
    next_from: typing.Optional[str] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetHistoryExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MessagesMessage"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
    conversations: typing.Optional[typing.List["MessagesConversation"]] = None


class GetHistoryResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MessagesMessage"]] = None


class GetImportantMessagesExtendedResponseModel(BaseResponse):
    messages: typing.Optional["MessagesMessagesArray"] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
    conversations: typing.Optional[typing.List["MessagesConversation"]] = None


class GetImportantMessagesResponseModel(BaseResponse):
    messages: typing.Optional["MessagesMessagesArray"] = None
    profiles: typing.Optional[typing.List["UsersUser"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
    conversations: typing.Optional[typing.List["MessagesConversation"]] = None


class GetIntentUsersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None


class GetInviteLinkResponseModel(BaseResponse):
    link: typing.Optional[str] = None


class GetLongPollHistoryResponseModel(BaseResponse):
    history: typing.Optional[typing.List["list"]] = None
    messages: typing.Optional["MessagesLongpollMessages"] = None
    credentials: typing.Optional["MessagesLongpollParams"] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
    chats: typing.Optional[typing.List["MessagesChat"]] = None
    new_pts: typing.Optional[int] = None
    from_pts: typing.Optional[int] = None
    more: typing.Optional[bool] = None
    conversations: typing.Optional[typing.List["MessagesConversation"]] = None


class IsMessagesFromGroupAllowedResponseModel(BaseResponse):
    is_allowed: typing.Optional["BaseBoolInt"] = None


class JoinChatByInviteLinkResponseModel(BaseResponse):
    chat_id: typing.Optional[int] = None


class SearchConversationsExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MessagesConversation"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class SearchConversationsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MessagesConversation"]] = None


class SearchExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MessagesMessage"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
    conversations: typing.Optional[typing.List["MessagesConversation"]] = None


class SearchResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["MessagesMessage"]] = None


class SetChatPhotoResponseModel(BaseResponse):
    message_id: typing.Optional[int] = None
    chat: typing.Optional["MessagesChat"] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "BaseBoolInt",
    "CreateChatResponse",
    "DeleteChatPhotoResponse",
    "DeleteChatPhotoResponseModel",
    "DeleteConversationResponse",
    "DeleteConversationResponseModel",
    "DeleteResponse",
    "EditResponse",
    "GetByConversationMessageIdExtendedResponse",
    "GetByConversationMessageIdExtendedResponseModel",
    "GetByConversationMessageIdResponse",
    "GetByConversationMessageIdResponseModel",
    "GetByIdExtendedResponse",
    "GetByIdExtendedResponseModel",
    "GetByIdResponse",
    "GetByIdResponseModel",
    "GetChatChatIdsFieldsResponse",
    "GetChatChatIdsResponse",
    "GetChatFieldsResponse",
    "GetChatPreviewResponse",
    "GetChatPreviewResponseModel",
    "GetChatResponse",
    "GetConversationMembersResponse",
    "GetConversationsByIdExtendedResponse",
    "GetConversationsByIdResponse",
    "GetConversationsResponse",
    "GetConversationsResponseModel",
    "GetHistoryAttachmentsResponse",
    "GetHistoryAttachmentsResponseModel",
    "GetHistoryExtendedResponse",
    "GetHistoryExtendedResponseModel",
    "GetHistoryResponse",
    "GetHistoryResponseModel",
    "GetImportantMessagesExtendedResponse",
    "GetImportantMessagesExtendedResponseModel",
    "GetImportantMessagesResponse",
    "GetImportantMessagesResponseModel",
    "GetIntentUsersResponse",
    "GetIntentUsersResponseModel",
    "GetInviteLinkResponse",
    "GetInviteLinkResponseModel",
    "GetLastActivityResponse",
    "GetLongPollHistoryResponse",
    "GetLongPollHistoryResponseModel",
    "GetLongPollServerResponse",
    "GroupsGroupFull",
    "IsMessagesFromGroupAllowedResponse",
    "IsMessagesFromGroupAllowedResponseModel",
    "JoinChatByInviteLinkResponse",
    "JoinChatByInviteLinkResponseModel",
    "MarkAsImportantResponse",
    "MessagesChat",
    "MessagesChatFull",
    "MessagesChatPreview",
    "MessagesConversation",
    "MessagesConversationWithMessage",
    "MessagesGetConversationById",
    "MessagesGetConversationByIdExtended",
    "MessagesGetConversationMembers",
    "MessagesHistoryAttachment",
    "MessagesLastActivity",
    "MessagesLongpollMessages",
    "MessagesLongpollParams",
    "MessagesMessage",
    "MessagesMessagesArray",
    "MessagesPinnedMessage",
    "MessagesSendUserIdsResponseItem",
    "PinResponse",
    "SearchConversationsExtendedResponse",
    "SearchConversationsExtendedResponseModel",
    "SearchConversationsResponse",
    "SearchConversationsResponseModel",
    "SearchExtendedResponse",
    "SearchExtendedResponseModel",
    "SearchResponse",
    "SearchResponseModel",
    "SendResponse",
    "SendUserIdsResponse",
    "SetChatPhotoResponse",
    "SetChatPhotoResponseModel",
    "UsersUser",
    "UsersUserFull",
)



import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import BaseBoolInt, OkResponse
from vkbottle_types.responses.market import (
    AddAlbumResponse,
    AddAlbumResponseModel,
    AddResponse,
    AddResponseModel,
    CreateCommentResponse,
    DeleteCommentResponse,
    GetAlbumByIdResponse,
    GetAlbumByIdResponseModel,
    GetAlbumsResponse,
    GetAlbumsResponseModel,
    GetByIdExtendedResponse,
    GetByIdExtendedResponseModel,
    GetByIdResponse,
    GetByIdResponseModel,
    GetCategoriesResponse,
    GetCategoriesResponseModel,
    GetCommentsResponse,
    GetCommentsResponseModel,
    GetExtendedResponse,
    GetExtendedResponseModel,
    GetGroupOrdersResponse,
    GetGroupOrdersResponseModel,
    GetOrderByIdResponse,
    GetOrderByIdResponseModel,
    GetOrderItemsResponse,
    GetOrderItemsResponseModel,
    GetOrdersExtendedResponse,
    GetOrdersExtendedResponseModel,
    GetOrdersResponse,
    GetOrdersResponseModel,
    GetResponse,
    GetResponseModel,
    RestoreCommentResponse,
    SearchExtendedResponse,
    SearchExtendedResponseModel,
    SearchResponse,
    SearchResponseModel,
)


class MarketCategory(BaseCategory):
    async def add(
        self,
        owner_id: int,
        name: str,
        description: str,
        category_id: int,
        price: typing.Optional[float] = None,
        old_price: typing.Optional[float] = None,
        deleted: typing.Optional[bool] = None,
        main_photo_id: typing.Optional[int] = None,
        photo_ids: typing.Optional[typing.List[int]] = None,
        url: typing.Optional[str] = None,
        dimension_width: typing.Optional[int] = None,
        dimension_height: typing.Optional[int] = None,
        dimension_length: typing.Optional[int] = None,
        weight: typing.Optional[int] = None,
        sku: typing.Optional[str] = None,
        **kwargs
    ) -> AddResponseModel:
        """Ads a new item to the market.

        :param owner_id: ID of an item owner community.
        :param name: Item name.
        :param description: Item description.
        :param category_id: Item category ID.
        :param price: Item price.
        :param old_price:
        :param deleted: Item status ('1' — deleted, '0' — not deleted).
        :param main_photo_id: Cover photo ID.
        :param photo_ids: IDs of additional photos.
        :param url: Url for button in market item.
        :param dimension_width:
        :param dimension_height:
        :param dimension_length:
        :param weight:
        :param sku:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.add", params)
        model = AddResponse
        return model(**response).response

    async def add_album(
        self,
        owner_id: int,
        title: str,
        photo_id: typing.Optional[int] = None,
        main_album: typing.Optional[bool] = None,
        is_hidden: typing.Optional[bool] = None,
        **kwargs
    ) -> AddAlbumResponseModel:
        """Creates new collection of items

        :param owner_id: ID of an item owner community.
        :param title: Collection title.
        :param photo_id: Cover photo ID.
        :param main_album: Set as main ('1' - set, '0' - no).
        :param is_hidden: Set as hidden
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.addAlbum", params)
        model = AddAlbumResponse
        return model(**response).response

    async def add_to_album(
        self,
        owner_id: int,
        item_ids: typing.List[int],
        album_ids: typing.List[int],
        **kwargs
    ) -> int:
        """Adds an item to one or multiple collections.

        :param owner_id: ID of an item owner community.
        :param item_ids:
        :param album_ids: Collections IDs to add item to.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.addToAlbum", params)
        model = OkResponse
        return model(**response).response

    async def create_comment(
        self,
        owner_id: int,
        item_id: int,
        message: typing.Optional[str] = None,
        attachments: typing.Optional[typing.List[str]] = None,
        from_group: typing.Optional[bool] = None,
        reply_to_comment: typing.Optional[int] = None,
        sticker_id: typing.Optional[int] = None,
        guid: typing.Optional[str] = None,
        **kwargs
    ) -> int:
        """Creates a new comment for an item.

        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        :param message: Comment text (required if 'attachments' parameter is not specified)
        :param attachments: Comma-separated list of objects attached to a comment. The field is submitted the following way: , "'<owner_id>_<media_id>,<owner_id>_<media_id>'", , '' - media attachment type: "'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document", , '<owner_id>' - media owner id, '<media_id>' - media attachment id, , For example: "photo100172_166443618,photo66748_265827614",
        :param from_group: '1' - comment will be published on behalf of a community, '0' - on behalf of a user (by default).
        :param reply_to_comment: ID of a comment to reply with current comment to.
        :param sticker_id: Sticker ID.
        :param guid: Random value to avoid resending one comment.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.createComment", params)
        model = CreateCommentResponse
        return model(**response).response

    async def delete(self, owner_id: int, item_id: int, **kwargs) -> int:
        """Deletes an item.

        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.delete", params)
        model = OkResponse
        return model(**response).response

    async def delete_album(self, owner_id: int, album_id: int, **kwargs) -> int:
        """Deletes a collection of items.

        :param owner_id: ID of an collection owner community.
        :param album_id: Collection ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.deleteAlbum", params)
        model = OkResponse
        return model(**response).response

    async def delete_comment(
        self, owner_id: int, comment_id: int, **kwargs
    ) -> BaseBoolInt:
        """Deletes an item's comment

        :param owner_id: identifier of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        :param comment_id: comment id
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.deleteComment", params)
        model = DeleteCommentResponse
        return model(**response).response

    async def edit(
        self,
        owner_id: int,
        item_id: int,
        name: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        category_id: typing.Optional[int] = None,
        price: typing.Optional[float] = None,
        old_price: typing.Optional[float] = None,
        deleted: typing.Optional[bool] = None,
        main_photo_id: typing.Optional[int] = None,
        photo_ids: typing.Optional[typing.List[int]] = None,
        url: typing.Optional[str] = None,
        dimension_width: typing.Optional[int] = None,
        dimension_height: typing.Optional[int] = None,
        dimension_length: typing.Optional[int] = None,
        weight: typing.Optional[int] = None,
        sku: typing.Optional[str] = None,
        **kwargs
    ) -> int:
        """Edits an item.

        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        :param name: Item name.
        :param description: Item description.
        :param category_id: Item category ID.
        :param price: Item price.
        :param old_price:
        :param deleted: Item status ('1' — deleted, '0' — not deleted).
        :param main_photo_id: Cover photo ID.
        :param photo_ids: IDs of additional photos.
        :param url: Url for button in market item.
        :param dimension_width:
        :param dimension_height:
        :param dimension_length:
        :param weight:
        :param sku:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.edit", params)
        model = OkResponse
        return model(**response).response

    async def edit_album(
        self,
        owner_id: int,
        album_id: int,
        title: str,
        photo_id: typing.Optional[int] = None,
        main_album: typing.Optional[bool] = None,
        is_hidden: typing.Optional[bool] = None,
        **kwargs
    ) -> int:
        """Edits a collection of items

        :param owner_id: ID of an collection owner community.
        :param album_id: Collection ID.
        :param title: Collection title.
        :param photo_id: Cover photo id
        :param main_album: Set as main ('1' - set, '0' - no).
        :param is_hidden: Set as hidden
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.editAlbum", params)
        model = OkResponse
        return model(**response).response

    async def edit_comment(
        self,
        owner_id: int,
        comment_id: int,
        message: typing.Optional[str] = None,
        attachments: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> int:
        """Chages item comment's text

        :param owner_id: ID of an item owner community.
        :param comment_id: Comment ID.
        :param message: New comment text (required if 'attachments' are not specified), , 2048 symbols maximum.
        :param attachments: Comma-separated list of objects attached to a comment. The field is submitted the following way: , "'<owner_id>_<media_id>,<owner_id>_<media_id>'", , '' - media attachment type: "'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document", , '<owner_id>' - media owner id, '<media_id>' - media attachment id, , For example: "photo100172_166443618,photo66748_265827614",
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.editComment", params)
        model = OkResponse
        return model(**response).response

    async def edit_order(
        self,
        user_id: int,
        order_id: int,
        merchant_comment: typing.Optional[str] = None,
        status: typing.Optional[int] = None,
        track_number: typing.Optional[str] = None,
        payment_status: typing.Optional[Literal["not_paid", "paid", "returned"]] = None,
        delivery_price: typing.Optional[int] = None,
        width: typing.Optional[int] = None,
        length: typing.Optional[int] = None,
        height: typing.Optional[int] = None,
        weight: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Edit order

        :param user_id:
        :param order_id:
        :param merchant_comment:
        :param status:
        :param track_number:
        :param payment_status:
        :param delivery_price:
        :param width:
        :param length:
        :param height:
        :param weight:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.editOrder", params)
        model = OkResponse
        return model(**response).response

    @typing.overload
    async def get(
        self,
        owner_id: int,
        album_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        extended: typing.Optional[Literal[False]] = ...,
        date_from: typing.Optional[str] = None,
        date_to: typing.Optional[str] = None,
        need_variants: typing.Optional[bool] = None,
        with_disabled: typing.Optional[bool] = None,
        **kwargs
    ) -> GetResponseModel:
        ...

    @typing.overload
    async def get(
        self,
        owner_id: int,
        album_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        extended: Literal[True] = ...,
        date_from: typing.Optional[str] = None,
        date_to: typing.Optional[str] = None,
        need_variants: typing.Optional[bool] = None,
        with_disabled: typing.Optional[bool] = None,
        **kwargs
    ) -> GetExtendedResponseModel:
        ...

    async def get(
        self,
        owner_id=None,
        album_id=None,
        count=None,
        offset=None,
        extended=None,
        date_from=None,
        date_to=None,
        need_variants=None,
        with_disabled=None,
        **kwargs
    ) -> typing.Union[GetResponseModel, GetExtendedResponseModel]:
        """Returns items list for a community.

        :param owner_id: ID of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        :param album_id:
        :param count: Number of items to return.
        :param offset: Offset needed to return a specific subset of results.
        :param extended: '1' - method will return additional fields: 'likes, can_comment, car_repost, photos'. These parameters are not returned by default.
        :param date_from: Items update date from (format: yyyy-mm-dd)
        :param date_to: Items update date to (format: yyyy-mm-dd)
        :param need_variants: Add variants to response if exist
        :param with_disabled: Add disabled items to response
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.get", params)
        model = self.get_model(
            ((("extended",), GetExtendedResponse),),
            default=GetResponse,
            params=params,
        )
        return model(**response).response

    async def get_album_by_id(
        self, owner_id: int, album_ids: typing.List[int], **kwargs
    ) -> GetAlbumByIdResponseModel:
        """Returns items album's data

        :param owner_id: identifier of an album owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        :param album_ids: collections identifiers to obtain data from
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getAlbumById", params)
        model = GetAlbumByIdResponse
        return model(**response).response

    async def get_albums(
        self,
        owner_id: int,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetAlbumsResponseModel:
        """Returns community's market collections list.

        :param owner_id: ID of an items owner community.
        :param offset: Offset needed to return a specific subset of results.
        :param count: Number of items to return.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getAlbums", params)
        model = GetAlbumsResponse
        return model(**response).response

    @typing.overload
    async def get_by_id(
        self,
        item_ids: typing.List[str],
        extended: typing.Optional[Literal[False]] = ...,
        **kwargs
    ) -> GetByIdResponseModel:
        ...

    @typing.overload
    async def get_by_id(
        self, item_ids: typing.List[str], extended: Literal[True] = ..., **kwargs
    ) -> GetByIdExtendedResponseModel:
        ...

    async def get_by_id(
        self, item_ids=None, extended=None, **kwargs
    ) -> typing.Union[GetByIdResponseModel, GetByIdExtendedResponseModel]:
        """Returns information about market items by their ids.

        :param item_ids: Comma-separated ids list: {user id}_{item id}. If an item belongs to a community -{community id} is used. " 'Videos' value example: , '-4363_136089719,13245770_137352259'"
        :param extended: '1' - to return additional fields: 'likes, can_comment, car_repost, photos'. By default: '0'.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getById", params)
        model = self.get_model(
            ((("extended",), GetByIdExtendedResponse),),
            default=GetByIdResponse,
            params=params,
        )
        return model(**response).response

    async def get_categories(
        self,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        **kwargs
    ) -> GetCategoriesResponseModel:
        """Returns a list of market categories.

        :param count: Number of results to return.
        :param offset: Offset needed to return a specific subset of results.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getCategories", params)
        model = GetCategoriesResponse
        return model(**response).response

    async def get_comments(
        self,
        owner_id: int,
        item_id: int,
        need_likes: typing.Optional[bool] = None,
        start_comment_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        sort: typing.Optional[Literal["asc", "desc"]] = None,
        extended: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> GetCommentsResponseModel:
        """Returns comments list for an item.

        :param owner_id: ID of an item owner community
        :param item_id: Item ID.
        :param need_likes: '1' — to return likes info.
        :param start_comment_id: ID of a comment to start a list from (details below).
        :param offset:
        :param count: Number of results to return.
        :param sort: Sort order ('asc' — from old to new, 'desc' — from new to old)
        :param extended: '1' — comments will be returned as numbered objects, in addition lists of 'profiles' and 'groups' objects will be returned.
        :param fields: List of additional profile fields to return. See the [vk.com/dev/fields|details]
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getComments", params)
        model = GetCommentsResponse
        return model(**response).response

    async def get_group_orders(
        self,
        group_id: int,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetGroupOrdersResponseModel:
        """Get market orders

        :param group_id:
        :param offset:
        :param count:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getGroupOrders", params)
        model = GetGroupOrdersResponse
        return model(**response).response

    async def get_order_by_id(
        self,
        order_id: int,
        user_id: typing.Optional[int] = None,
        extended: typing.Optional[bool] = None,
        **kwargs
    ) -> GetOrderByIdResponseModel:
        """Get order

        :param order_id:
        :param user_id:
        :param extended:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getOrderById", params)
        model = GetOrderByIdResponse
        return model(**response).response

    async def get_order_items(
        self,
        order_id: int,
        user_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetOrderItemsResponseModel:
        """Get market items in the order

        :param order_id:
        :param user_id:
        :param offset:
        :param count:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getOrderItems", params)
        model = GetOrderItemsResponse
        return model(**response).response

    @typing.overload
    async def get_orders(
        self,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: typing.Optional[Literal[False]] = ...,
        date_from: typing.Optional[str] = None,
        date_to: typing.Optional[str] = None,
        **kwargs
    ) -> GetOrdersResponseModel:
        ...

    @typing.overload
    async def get_orders(
        self,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: Literal[True] = ...,
        date_from: typing.Optional[str] = None,
        date_to: typing.Optional[str] = None,
        **kwargs
    ) -> GetOrdersExtendedResponseModel:
        ...

    async def get_orders(
        self,
        offset=None,
        count=None,
        extended=None,
        date_from=None,
        date_to=None,
        **kwargs
    ) -> typing.Union[GetOrdersResponseModel, GetOrdersExtendedResponseModel]:
        """market.getOrders method

        :param offset:
        :param count:
        :param extended:
        :param date_from: Orders status updated date from (format: yyyy-mm-dd)
        :param date_to: Orders status updated date to (format: yyyy-mm-dd)
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getOrders", params)
        model = self.get_model(
            ((("extended",), GetOrdersExtendedResponse),),
            default=GetOrdersResponse,
            params=params,
        )
        return model(**response).response

    async def remove_from_album(
        self, owner_id: int, item_id: int, album_ids: typing.List[int], **kwargs
    ) -> int:
        """Removes an item from one or multiple collections.

        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        :param album_ids: Collections IDs to remove item from.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.removeFromAlbum", params)
        model = OkResponse
        return model(**response).response

    async def reorder_albums(
        self,
        owner_id: int,
        album_id: int,
        before: typing.Optional[int] = None,
        after: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Reorders the collections list.

        :param owner_id: ID of an item owner community.
        :param album_id: Collection ID.
        :param before: ID of a collection to place current collection before it.
        :param after: ID of a collection to place current collection after it.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.reorderAlbums", params)
        model = OkResponse
        return model(**response).response

    async def reorder_items(
        self,
        owner_id: int,
        item_id: int,
        album_id: typing.Optional[int] = None,
        before: typing.Optional[int] = None,
        after: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Changes item place in a collection.

        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        :param album_id: ID of a collection to reorder items in. Set 0 to reorder full items list.
        :param before: ID of an item to place current item before it.
        :param after: ID of an item to place current item after it.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.reorderItems", params)
        model = OkResponse
        return model(**response).response

    async def report(
        self,
        owner_id: int,
        item_id: int,
        reason: typing.Optional[Literal[0, 1, 2, 3, 4, 5, 6]] = None,
        **kwargs
    ) -> int:
        """Sends a complaint to the item.

        :param owner_id: ID of an item owner community.
        :param item_id: Item ID.
        :param reason: Complaint reason. Possible values: *'0' — spam,, *'1' — child porn,, *'2' — extremism,, *'3' — violence,, *'4' — drugs propaganda,, *'5' — adult materials,, *'6' — insult.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.report", params)
        model = OkResponse
        return model(**response).response

    async def report_comment(
        self,
        owner_id: int,
        comment_id: int,
        reason: Literal[0, 1, 2, 3, 4, 5, 6],
        **kwargs
    ) -> int:
        """Sends a complaint to the item's comment.

        :param owner_id: ID of an item owner community.
        :param comment_id: Comment ID.
        :param reason: Complaint reason. Possible values: *'0' — spam,, *'1' — child porn,, *'2' — extremism,, *'3' — violence,, *'4' — drugs propaganda,, *'5' — adult materials,, *'6' — insult.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.reportComment", params)
        model = OkResponse
        return model(**response).response

    async def restore(self, owner_id: int, item_id: int, **kwargs) -> int:
        """Restores recently deleted item

        :param owner_id: ID of an item owner community.
        :param item_id: Deleted item ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.restore", params)
        model = OkResponse
        return model(**response).response

    async def restore_comment(
        self, owner_id: int, comment_id: int, **kwargs
    ) -> BaseBoolInt:
        """Restores a recently deleted comment

        :param owner_id: identifier of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        :param comment_id: deleted comment id
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.restoreComment", params)
        model = RestoreCommentResponse
        return model(**response).response

    @typing.overload
    async def search(
        self,
        owner_id: int,
        album_id: typing.Optional[int] = None,
        q: typing.Optional[str] = None,
        price_from: typing.Optional[int] = None,
        price_to: typing.Optional[int] = None,
        sort: typing.Optional[Literal[0, 1, 2, 3]] = None,
        rev: typing.Optional[Literal[0, 1]] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: typing.Optional[Literal[False]] = ...,
        status: typing.Optional[typing.List[int]] = None,
        need_variants: typing.Optional[bool] = None,
        **kwargs
    ) -> SearchResponseModel:
        ...

    @typing.overload
    async def search(
        self,
        owner_id: int,
        album_id: typing.Optional[int] = None,
        q: typing.Optional[str] = None,
        price_from: typing.Optional[int] = None,
        price_to: typing.Optional[int] = None,
        sort: typing.Optional[Literal[0, 1, 2, 3]] = None,
        rev: typing.Optional[Literal[0, 1]] = None,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        extended: Literal[True] = ...,
        status: typing.Optional[typing.List[int]] = None,
        need_variants: typing.Optional[bool] = None,
        **kwargs
    ) -> SearchExtendedResponseModel:
        ...

    async def search(
        self,
        owner_id=None,
        album_id=None,
        q=None,
        price_from=None,
        price_to=None,
        sort=None,
        rev=None,
        offset=None,
        count=None,
        extended=None,
        status=None,
        need_variants=None,
        **kwargs
    ) -> typing.Union[SearchResponseModel, SearchExtendedResponseModel]:
        """Searches market items in a community's catalog

        :param owner_id: ID of an items owner community.
        :param album_id:
        :param q: Search query, for example "pink slippers".
        :param price_from: Minimum item price value.
        :param price_to: Maximum item price value.
        :param sort:
        :param rev: '0' — do not use reverse order, '1' — use reverse order
        :param offset: Offset needed to return a specific subset of results.
        :param count: Number of items to return.
        :param extended: '1' - to return additional fields: 'likes, can_comment, car_repost, photos'. By default: '0'.
        :param status:
        :param need_variants: Add variants to response if exist
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.search", params)
        model = self.get_model(
            ((("extended",), SearchExtendedResponse),),
            default=SearchResponse,
            params=params,
        )
        return model(**response).response

    async def search_items(
        self,
        q: str,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        category_id: typing.Optional[int] = None,
        price_from: typing.Optional[int] = None,
        price_to: typing.Optional[int] = None,
        sort_by: typing.Optional[Literal[1, 2, 3]] = None,
        sort_direction: typing.Optional[Literal[0, 1]] = None,
        country: typing.Optional[int] = None,
        city: typing.Optional[int] = None,
        **kwargs
    ) -> SearchResponseModel:
        """market.searchItems method

        :param q:
        :param offset:
        :param count:
        :param category_id:
        :param price_from:
        :param price_to:
        :param sort_by:
        :param sort_direction:
        :param country:
        :param city:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.searchItems", params)
        model = SearchResponse
        return model(**response).response


__all__ = ("MarketCategory",)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import OkResponse
from vkbottle_types.responses.store import (
    BaseSticker,
    GetFavoriteStickersResponse,
    GetProductsResponse,
    GetStickersKeywordsResponse,
    GetStickersKeywordsResponseModel,
    StoreProduct,
)


class StoreCategory(BaseCategory):
    async def add_stickers_to_favorite(
        self, sticker_ids: typing.List[int], **kwargs
    ) -> int:
        """Adds given sticker IDs to the list of user's favorite stickers

        :param sticker_ids: Sticker IDs to be added
        """

        params = self.get_set_params(locals())
        response = await self.api.request("store.addStickersToFavorite", params)
        model = OkResponse
        return model(**response).response

    async def get_favorite_stickers(self, **kwargs) -> typing.List[BaseSticker]:
        """store.getFavoriteStickers method"""

        params = self.get_set_params(locals())
        response = await self.api.request("store.getFavoriteStickers", params)
        model = GetFavoriteStickersResponse
        return model(**response).response

    async def get_products(
        self,
        type: typing.Optional[str] = None,
        merchant: typing.Optional[str] = None,
        section: typing.Optional[str] = None,
        product_ids: typing.Optional[typing.List[int]] = None,
        filters: typing.Optional[typing.List[str]] = None,
        extended: typing.Optional[bool] = None,
        **kwargs
    ) -> typing.List[StoreProduct]:
        """store.getProducts method

        :param type:
        :param merchant:
        :param section:
        :param product_ids:
        :param filters:
        :param extended:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("store.getProducts", params)
        model = GetProductsResponse
        return model(**response).response

    async def get_stickers_keywords(
        self,
        stickers_ids: typing.Optional[typing.List[int]] = None,
        products_ids: typing.Optional[typing.List[int]] = None,
        aliases: typing.Optional[bool] = None,
        all_products: typing.Optional[bool] = None,
        need_stickers: typing.Optional[bool] = None,
        **kwargs
    ) -> GetStickersKeywordsResponseModel:
        """store.getStickersKeywords method

        :param stickers_ids:
        :param products_ids:
        :param aliases:
        :param all_products:
        :param need_stickers:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("store.getStickersKeywords", params)
        model = GetStickersKeywordsResponse
        return model(**response).response

    async def remove_stickers_from_favorite(
        self, sticker_ids: typing.List[int], **kwargs
    ) -> int:
        """Removes given sticker IDs from the list of user's favorite stickers

        :param sticker_ids: Sticker IDs to be removed
        """

        params = self.get_set_params(locals())
        response = await self.api.request("store.removeStickersFromFavorite", params)
        model = OkResponse
        return model(**response).response


__all__ = ("StoreCategory",)



import inspect
import typing

from vkbottle_types.objects import (
    GroupsGroup,
    GroupsGroupFull,
    UsersUser,
    UsersUserFull,
    WallWallComment,
    WallWallpostFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class CreateCommentResponse(BaseResponse):
    response: "CreateCommentResponseModel"


class EditResponse(BaseResponse):
    response: "EditResponseModel"


class GetByIdExtendedResponse(BaseResponse):
    response: "GetByIdExtendedResponseModel"


class GetByIdLegacyResponse(BaseResponse):
    response: typing.List["WallWallpostFull"]


class GetByIdResponse(BaseResponse):
    response: "GetByIdResponseModel"


class GetCommentExtendedResponse(BaseResponse):
    response: "GetCommentExtendedResponseModel"


class GetCommentResponse(BaseResponse):
    response: "GetCommentResponseModel"


class GetCommentsExtendedResponse(BaseResponse):
    response: "GetCommentsExtendedResponseModel"


class GetCommentsResponse(BaseResponse):
    response: "GetCommentsResponseModel"


class GetRepostsResponse(BaseResponse):
    response: "GetRepostsResponseModel"


class GetExtendedResponse(BaseResponse):
    response: "GetExtendedResponseModel"


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class PostAdsStealthResponse(BaseResponse):
    response: "PostAdsStealthResponseModel"


class PostResponse(BaseResponse):
    response: "PostResponseModel"


class RepostResponse(BaseResponse):
    response: "RepostResponseModel"


class SearchExtendedResponse(BaseResponse):
    response: "SearchExtendedResponseModel"


class SearchResponse(BaseResponse):
    response: "SearchResponseModel"


class CreateCommentResponseModel(BaseResponse):
    comment_id: typing.Optional[int] = None


class EditResponseModel(BaseResponse):
    post_id: typing.Optional[int] = None


class GetByIdExtendedResponseModel(BaseResponse):
    items: typing.Optional[typing.List["WallWallpostFull"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetByIdResponseModel(BaseResponse):
    items: typing.Optional[typing.List["WallWallpostFull"]] = None


class GetCommentExtendedResponseModel(BaseResponse):
    items: typing.Optional[typing.List["WallWallComment"]] = None
    profiles: typing.Optional[typing.List["UsersUser"]] = None
    groups: typing.Optional[typing.List["GroupsGroup"]] = None


class GetCommentResponseModel(BaseResponse):
    items: typing.Optional[typing.List["WallWallComment"]] = None


class GetCommentsExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallComment"]] = None
    profiles: typing.Optional[typing.List["UsersUser"]] = None
    groups: typing.Optional[typing.List["GroupsGroup"]] = None
    current_level_count: typing.Optional[int] = None
    can_post: typing.Optional[bool] = None
    show_reply_button: typing.Optional[bool] = None
    groups_can_post: typing.Optional[bool] = None


class GetCommentsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallComment"]] = None
    current_level_count: typing.Optional[int] = None
    can_post: typing.Optional[bool] = None
    show_reply_button: typing.Optional[bool] = None
    groups_can_post: typing.Optional[bool] = None


class GetRepostsResponseModel(BaseResponse):
    items: typing.Optional[typing.List["WallWallpostFull"]] = None
    profiles: typing.Optional[typing.List["UsersUser"]] = None
    groups: typing.Optional[typing.List["GroupsGroup"]] = None


class GetExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallpostFull"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallpostFull"]] = None


class PostAdsStealthResponseModel(BaseResponse):
    post_id: typing.Optional[int] = None


class PostResponseModel(BaseResponse):
    post_id: typing.Optional[int] = None


class RepostResponseModel(BaseResponse):
    success: typing.Optional[int] = None
    post_id: typing.Optional[int] = None
    reposts_count: typing.Optional[int] = None
    wall_repost_count: typing.Optional[int] = None
    mail_repost_count: typing.Optional[int] = None
    likes_count: typing.Optional[int] = None


class SearchExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallpostFull"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class SearchResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallpostFull"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "CreateCommentResponse",
    "CreateCommentResponseModel",
    "EditResponse",
    "EditResponseModel",
    "GetByIdExtendedResponse",
    "GetByIdExtendedResponseModel",
    "GetByIdLegacyResponse",
    "GetByIdResponse",
    "GetByIdResponseModel",
    "GetCommentExtendedResponse",
    "GetCommentExtendedResponseModel",
    "GetCommentResponse",
    "GetCommentResponseModel",
    "GetCommentsExtendedResponse",
    "GetCommentsExtendedResponseModel",
    "GetCommentsResponse",
    "GetCommentsResponseModel",
    "GetExtendedResponse",
    "GetExtendedResponseModel",
    "GetRepostsResponse",
    "GetRepostsResponseModel",
    "GetResponse",
    "GetResponseModel",
    "GroupsGroup",
    "GroupsGroupFull",
    "PostAdsStealthResponse",
    "PostAdsStealthResponseModel",
    "PostResponse",
    "PostResponseModel",
    "RepostResponse",
    "RepostResponseModel",
    "SearchExtendedResponse",
    "SearchExtendedResponseModel",
    "SearchResponse",
    "SearchResponseModel",
    "UsersUser",
    "UsersUserFull",
    "WallWallComment",
    "WallWallpostFull",
)



import inspect
import typing

from vkbottle_types.objects import (
    FaveBookmark,
    FavePage,
    FaveTag,
    GroupsGroup,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class AddTagResponse(BaseResponse):
    response: FaveTag


class GetPagesResponse(BaseResponse):
    response: "GetPagesResponseModel"


class GetTagsResponse(BaseResponse):
    response: "GetTagsResponseModel"


class GetExtendedResponse(BaseResponse):
    response: "GetExtendedResponseModel"


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class GetPagesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["FavePage"]] = None


class GetTagsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["FaveTag"]] = None


class GetExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["FaveBookmark"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroup"]] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["FaveBookmark"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AddTagResponse",
    "FaveBookmark",
    "FavePage",
    "FaveTag",
    "GetExtendedResponse",
    "GetExtendedResponseModel",
    "GetPagesResponse",
    "GetPagesResponseModel",
    "GetResponse",
    "GetResponseModel",
    "GetTagsResponse",
    "GetTagsResponseModel",
    "GroupsGroup",
    "UsersUserFull",
)



import inspect
import typing

from vkbottle_types.objects import BaseBoolInt, PollsBackground, PollsPoll, PollsVoters
from vkbottle_types.responses.base_response import BaseResponse


class AddVoteResponse(BaseResponse):
    response: BaseBoolInt


class CreateResponse(BaseResponse):
    response: PollsPoll


class DeleteVoteResponse(BaseResponse):
    response: BaseBoolInt


class GetBackgroundsResponse(BaseResponse):
    response: typing.List["PollsBackground"]


class GetByIdResponse(BaseResponse):
    response: PollsPoll


class GetVotersResponse(BaseResponse):
    response: typing.List["PollsVoters"]


class SavePhotoResponse(BaseResponse):
    response: PollsBackground


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AddVoteResponse",
    "BaseBoolInt",
    "CreateResponse",
    "DeleteVoteResponse",
    "GetBackgroundsResponse",
    "GetByIdResponse",
    "GetVotersResponse",
    "PollsBackground",
    "PollsPoll",
    "PollsVoters",
    "SavePhotoResponse",
)



class BaseStateGroup:
    def __init__(self, *args, **kwargs):
        raise DeprecationWarning(
            "BaseStateGroup from vkbottle_types is deprecated "
            "and will be removed in future releases, "
            "use vkbottle.BaseStateGroup instead",
        )

    def __init_subclass__(cls) -> None:
        raise DeprecationWarning(
            "BaseStateGroup from vkbottle_types is deprecated "
            "and will be removed in future releases, "
            "use vkbottle.BaseStateGroup instead",
        )


class StatePeer:
    def __init__(self, *args, **kwargs):
        raise DeprecationWarning(
            "StatePeer from vkbottle_types is deprecated "
            "and will be removed in future releases, "
            "use vkbottle.StatePeer instead"
        )

    def __init_subclass__(cls):
        raise DeprecationWarning(
            "StatePeer from vkbottle_types is deprecated "
            "and will be removed in future releases, "
            "use vkbottle.StatePeer instead"
        )



import inspect
import typing

from vkbottle_types.objects import (
    BaseBoolInt,
    BoardDefaultOrder,
    BoardTopic,
    BoardTopicComment,
    GroupsGroupFull,
    PollsPoll,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class AddTopicResponse(BaseResponse):
    response: int


class CreateCommentResponse(BaseResponse):
    response: int


class GetCommentsExtendedResponse(BaseResponse):
    response: "GetCommentsExtendedResponseModel"


class GetCommentsResponse(BaseResponse):
    response: "GetCommentsResponseModel"


class GetTopicsExtendedResponse(BaseResponse):
    response: "GetTopicsExtendedResponseModel"


class GetTopicsResponse(BaseResponse):
    response: "GetTopicsResponseModel"


class GetCommentsExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["BoardTopicComment"]] = None
    poll: typing.Optional[typing.Any] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None
    real_offset: typing.Optional[int] = None


class GetCommentsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["BoardTopicComment"]] = None
    poll: typing.Optional[typing.Any] = None
    real_offset: typing.Optional[int] = None


class GetTopicsExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["BoardTopic"]] = None
    default_order: typing.Optional["BoardDefaultOrder"] = None
    can_add_topics: typing.Optional["BaseBoolInt"] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetTopicsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["BoardTopic"]] = None
    default_order: typing.Optional["BoardDefaultOrder"] = None
    can_add_topics: typing.Optional["BaseBoolInt"] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AddTopicResponse",
    "BaseBoolInt",
    "BoardDefaultOrder",
    "BoardTopic",
    "BoardTopicComment",
    "CreateCommentResponse",
    "GetCommentsExtendedResponse",
    "GetCommentsExtendedResponseModel",
    "GetCommentsResponse",
    "GetCommentsResponseModel",
    "GetTopicsExtendedResponse",
    "GetTopicsExtendedResponseModel",
    "GetTopicsResponse",
    "GetTopicsResponseModel",
    "GroupsGroupFull",
    "PollsPoll",
    "UsersUserFull",
)



from .events import GroupTypes, UserTypes
from .state import BaseStateGroup, StatePeer

API_URL = "https://api.vk.com/method/"
API_VERSION = "5.131"

__all__ = (
    "GroupTypes",
    "UserTypes",
    "API_URL",
    "API_VERSION",
    "BaseStateGroup",
    "StatePeer",
)



import inspect
import typing

from vkbottle_types.responses.base_response import BaseResponse


class PaidStatusResponse(BaseResponse):
    response: "PaidStatusResponseModel"


class PaidStatusResponseModel(BaseResponse):
    is_paid: typing.Optional[bool] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "PaidStatusResponse",
    "PaidStatusResponseModel",
)



import inspect
import typing

from vkbottle_types.objects import BaseBoolInt, UsersUserMin
from vkbottle_types.responses.base_response import BaseResponse


class AddResponse(BaseResponse):
    response: "AddResponseModel"


class DeleteResponse(BaseResponse):
    response: "DeleteResponseModel"


class GetListExtendedResponse(BaseResponse):
    response: "GetListExtendedResponseModel"


class GetListResponse(BaseResponse):
    response: "GetListResponseModel"


class IsLikedResponse(BaseResponse):
    response: "IsLikedResponseModel"


class AddResponseModel(BaseResponse):
    likes: typing.Optional[int] = None


class DeleteResponseModel(BaseResponse):
    likes: typing.Optional[int] = None


class GetListExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserMin"]] = None


class GetListResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None


class IsLikedResponseModel(BaseResponse):
    liked: typing.Optional["BaseBoolInt"] = None
    copied: typing.Optional["BaseBoolInt"] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AddResponse",
    "AddResponseModel",
    "BaseBoolInt",
    "DeleteResponse",
    "DeleteResponseModel",
    "GetListExtendedResponse",
    "GetListExtendedResponseModel",
    "GetListResponse",
    "GetListResponseModel",
    "IsLikedResponse",
    "IsLikedResponseModel",
    "UsersUserMin",
)
